<?php
/**
 * Google fonts array
 * Define google font array
 */
if ( ! function_exists( 'penci_list_google_fonts_array' ) ) {
	function penci_list_google_fonts_array() {

		$penci_soledad_google_fonts = [
			'"ABeeZee", "regular:italic", sans-serif'                                                                                                                                    => 'ABeeZee',
			'"ADLaM Display", "regular", display'                                                                                                                                        => 'ADLaM Display',
			'"AR One Sans", "regular:500:600:700", sans-serif'                                                                                                                           => 'AR One Sans',
			'"Abel", "regular", sans-serif'                                                                                                                                              => 'Abel',
			'"Abhaya Libre", "regular:500:600:700:800", serif'                                                                                                                           => 'Abhaya Libre',
			'"Aboreto", "regular", display'                                                                                                                                              => 'Aboreto',
			'"Abril Fatface", "regular", display'                                                                                                                                        => 'Abril Fatface',
			'"Abyssinica SIL", "regular", serif'                                                                                                                                         => 'Abyssinica SIL',
			'"Aclonica", "regular", sans-serif'                                                                                                                                          => 'Aclonica',
			'"Acme", "regular", sans-serif'                                                                                                                                              => 'Acme',
			'"Actor", "regular", sans-serif'                                                                                                                                             => 'Actor',
			'"Adamina", "regular", serif'                                                                                                                                                => 'Adamina',
			'"Advent Pro", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                 => 'Advent Pro',
			'"Afacad", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                           => 'Afacad',
			'"Agbalumo", "regular", display'                                                                                                                                             => 'Agbalumo',
			'"Agdasima", "regular:700", sans-serif'                                                                                                                                      => 'Agdasima',
			'"Aguafina Script", "regular", handwriting'                                                                                                                                  => 'Aguafina Script',
			'"Akatab", "regular:500:600:700:800:900", sans-serif'                                                                                                                        => 'Akatab',
			'"Akaya Kanadaka", "regular", display'                                                                                                                                       => 'Akaya Kanadaka',
			'"Akaya Telivigala", "regular", display'                                                                                                                                     => 'Akaya Telivigala',
			'"Akronim", "regular", display'                                                                                                                                              => 'Akronim',
			'"Akshar", "300:regular:500:600:700", sans-serif'                                                                                                                            => 'Akshar',
			'"Aladin", "regular", display'                                                                                                                                               => 'Aladin',
			'"Alata", "regular", sans-serif'                                                                                                                                             => 'Alata',
			'"Alatsi", "regular", sans-serif'                                                                                                                                            => 'Alatsi',
			'"Albert Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                => 'Albert Sans',
			'"Aldrich", "regular", sans-serif'                                                                                                                                           => 'Aldrich',
			'"Alef", "regular:700", sans-serif'                                                                                                                                          => 'Alef',
			'"Alegreya", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                                  => 'Alegreya',
			'"Alegreya SC", "regular:italic:500:500italic:700:700italic:800:800italic:900:900italic", serif'                                                                             => 'Alegreya SC',
			'"Alegreya Sans", "100:100italic:300:300italic:regular:italic:500:500italic:700:700italic:800:800italic:900:900italic", sans-serif'                                          => 'Alegreya Sans',
			'"Alegreya Sans SC", "100:100italic:300:300italic:regular:italic:500:500italic:700:700italic:800:800italic:900:900italic", sans-serif'                                       => 'Alegreya Sans SC',
			'"Aleo", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                            => 'Aleo',
			'"Alex Brush", "regular", handwriting'                                                                                                                                       => 'Alex Brush',
			'"Alexandria", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                        => 'Alexandria',
			'"Alfa Slab One", "regular", display'                                                                                                                                        => 'Alfa Slab One',
			'"Alice", "regular", serif'                                                                                                                                                  => 'Alice',
			'"Alike", "regular", serif'                                                                                                                                                  => 'Alike',
			'"Alike Angular", "regular", serif'                                                                                                                                          => 'Alike Angular',
			'"Alkalami", "regular", serif'                                                                                                                                               => 'Alkalami',
			'"Alkatra", "regular:500:600:700", display'                                                                                                                                  => 'Alkatra',
			'"Allan", "regular:700", display'                                                                                                                                            => 'Allan',
			'"Allerta", "regular", sans-serif'                                                                                                                                           => 'Allerta',
			'"Allerta Stencil", "regular", sans-serif'                                                                                                                                   => 'Allerta Stencil',
			'"Allison", "regular", handwriting'                                                                                                                                          => 'Allison',
			'"Allura", "regular", handwriting'                                                                                                                                           => 'Allura',
			'"Almarai", "300:regular:700:800", sans-serif'                                                                                                                               => 'Almarai',
			'"Almendra", "regular:italic:700:700italic", serif'                                                                                                                          => 'Almendra',
			'"Almendra Display", "regular", display'                                                                                                                                     => 'Almendra Display',
			'"Almendra SC", "regular", serif'                                                                                                                                            => 'Almendra SC',
			'"Alumni Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                => 'Alumni Sans',
			'"Alumni Sans Collegiate One", "regular:italic", sans-serif'                                                                                                                 => 'Alumni Sans Collegiate One',
			'"Alumni Sans Inline One", "regular:italic", display'                                                                                                                        => 'Alumni Sans Inline One',
			'"Alumni Sans Pinstripe", "regular:italic", sans-serif'                                                                                                                      => 'Alumni Sans Pinstripe',
			'"Amarante", "regular", display'                                                                                                                                             => 'Amarante',
			'"Amaranth", "regular:italic:700:700italic", sans-serif'                                                                                                                     => 'Amaranth',
			'"Amatic SC", "regular:700", handwriting'                                                                                                                                    => 'Amatic SC',
			'"Amethysta", "regular", serif'                                                                                                                                              => 'Amethysta',
			'"Amiko", "regular:600:700", sans-serif'                                                                                                                                     => 'Amiko',
			'"Amiri", "regular:italic:700:700italic", serif'                                                                                                                             => 'Amiri',
			'"Amiri Quran", "regular", serif'                                                                                                                                            => 'Amiri Quran',
			'"Amita", "regular:700", handwriting'                                                                                                                                        => 'Amita',
			'"Anaheim", "regular:500:600:700:800", sans-serif'                                                                                                                           => 'Anaheim',
			'"Andada Pro", "regular:500:600:700:800:italic:500italic:600italic:700italic:800italic", serif'                                                                              => 'Andada Pro',
			'"Andika", "regular:italic:700:700italic", sans-serif'                                                                                                                       => 'Andika',
			'"Anek Bangla", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                           => 'Anek Bangla',
			'"Anek Devanagari", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                       => 'Anek Devanagari',
			'"Anek Gujarati", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                         => 'Anek Gujarati',
			'"Anek Gurmukhi", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                         => 'Anek Gurmukhi',
			'"Anek Kannada", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                          => 'Anek Kannada',
			'"Anek Latin", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                            => 'Anek Latin',
			'"Anek Malayalam", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                        => 'Anek Malayalam',
			'"Anek Odia", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                             => 'Anek Odia',
			'"Anek Tamil", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                            => 'Anek Tamil',
			'"Anek Telugu", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                           => 'Anek Telugu',
			'"Angkor", "regular", display'                                                                                                                                               => 'Angkor',
			'"Annapurna SIL", "regular:700", serif'                                                                                                                                      => 'Annapurna SIL',
			'"Annie Use Your Telescope", "regular", handwriting'                                                                                                                         => 'Annie Use Your Telescope',
			'"Anonymous Pro", "regular:italic:700:700italic", monospace'                                                                                                                 => 'Anonymous Pro',
			'"Anta", "regular", sans-serif'                                                                                                                                              => 'Anta',
			'"Antic", "regular", sans-serif'                                                                                                                                             => 'Antic',
			'"Antic Didone", "regular", serif'                                                                                                                                           => 'Antic Didone',
			'"Antic Slab", "regular", serif'                                                                                                                                             => 'Antic Slab',
			'"Anton", "regular", sans-serif'                                                                                                                                             => 'Anton',
			'"Anton SC", "regular", sans-serif'                                                                                                                                          => 'Anton SC',
			'"Antonio", "100:200:300:regular:500:600:700", sans-serif'                                                                                                                   => 'Antonio',
			'"Anuphan", "100:200:300:regular:500:600:700", sans-serif'                                                                                                                   => 'Anuphan',
			'"Anybody", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", display'                       => 'Anybody',
			'"Aoboshi One", "regular", serif'                                                                                                                                            => 'Aoboshi One',
			'"Arapey", "regular:italic", serif'                                                                                                                                          => 'Arapey',
			'"Arbutus", "regular", serif'                                                                                                                                                => 'Arbutus',
			'"Arbutus Slab", "regular", serif'                                                                                                                                           => 'Arbutus Slab',
			'"Architects Daughter", "regular", handwriting'                                                                                                                              => 'Architects Daughter',
			'"Archivo", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'Archivo',
			'"Archivo Black", "regular", sans-serif'                                                                                                                                     => 'Archivo Black',
			'"Archivo Narrow", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                   => 'Archivo Narrow',
			'"Are You Serious", "regular", handwriting'                                                                                                                                  => 'Are You Serious',
			'"Aref Ruqaa", "regular:700", serif'                                                                                                                                         => 'Aref Ruqaa',
			'"Aref Ruqaa Ink", "regular:700", serif'                                                                                                                                     => 'Aref Ruqaa Ink',
			'"Arima", "100:200:300:regular:500:600:700", display'                                                                                                                        => 'Arima',
			'"Arimo", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                            => 'Arimo',
			'"Arizonia", "regular", handwriting'                                                                                                                                         => 'Arizonia',
			'"Armata", "regular", sans-serif'                                                                                                                                            => 'Armata',
			'"Arsenal", "regular:italic:700:700italic", sans-serif'                                                                                                                      => 'Arsenal',
			'"Arsenal SC", "regular:italic:700:700italic", sans-serif'                                                                                                                   => 'Arsenal SC',
			'"Artifika", "regular", serif'                                                                                                                                               => 'Artifika',
			'"Arvo", "regular:italic:700:700italic", serif'                                                                                                                              => 'Arvo',
			'"Arya", "regular:700", sans-serif'                                                                                                                                          => 'Arya',
			'"Asap", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                       => 'Asap',
			'"Asap Condensed", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                           => 'Asap Condensed',
			'"Asar", "regular", serif'                                                                                                                                                   => 'Asar',
			'"Asset", "regular", display'                                                                                                                                                => 'Asset',
			'"Assistant", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                 => 'Assistant',
			'"Astloch", "regular:700", display'                                                                                                                                          => 'Astloch',
			'"Asul", "regular:700", sans-serif'                                                                                                                                          => 'Asul',
			'"Athiti", "200:300:regular:500:600:700", sans-serif'                                                                                                                        => 'Athiti',
			'"Atkinson Hyperlegible", "regular:italic:700:700italic", sans-serif'                                                                                                        => 'Atkinson Hyperlegible',
			'"Atma", "300:regular:500:600:700", display'                                                                                                                                 => 'Atma',
			'"Atomic Age", "regular", display'                                                                                                                                           => 'Atomic Age',
			'"Aubrey", "regular", display'                                                                                                                                               => 'Aubrey',
			'"Audiowide", "regular", display'                                                                                                                                            => 'Audiowide',
			'"Autour One", "regular", display'                                                                                                                                           => 'Autour One',
			'"Average", "regular", serif'                                                                                                                                                => 'Average',
			'"Average Sans", "regular", sans-serif'                                                                                                                                      => 'Average Sans',
			'"Averia Gruesa Libre", "regular", display'                                                                                                                                  => 'Averia Gruesa Libre',
			'"Averia Libre", "300:300italic:regular:italic:700:700italic", display'                                                                                                      => 'Averia Libre',
			'"Averia Sans Libre", "300:300italic:regular:italic:700:700italic", display'                                                                                                 => 'Averia Sans Libre',
			'"Averia Serif Libre", "300:300italic:regular:italic:700:700italic", display'                                                                                                => 'Averia Serif Libre',
			'"Azeret Mono", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", monospace'                 => 'Azeret Mono',
			'"B612", "regular:italic:700:700italic", sans-serif'                                                                                                                         => 'B612',
			'"B612 Mono", "regular:italic:700:700italic", monospace'                                                                                                                     => 'B612 Mono',
			'"BIZ UDGothic", "regular:700", sans-serif'                                                                                                                                  => 'BIZ UDGothic',
			'"BIZ UDMincho", "regular:700", serif'                                                                                                                                       => 'BIZ UDMincho',
			'"BIZ UDPGothic", "regular:700", sans-serif'                                                                                                                                 => 'BIZ UDPGothic',
			'"BIZ UDPMincho", "regular:700", serif'                                                                                                                                      => 'BIZ UDPMincho',
			'"Babylonica", "regular", handwriting'                                                                                                                                       => 'Babylonica',
			'"Bacasime Antique", "regular", serif'                                                                                                                                       => 'Bacasime Antique',
			'"Bad Script", "regular", handwriting'                                                                                                                                       => 'Bad Script',
			'"Bagel Fat One", "regular", display'                                                                                                                                        => 'Bagel Fat One',
			'"Bahiana", "regular", display'                                                                                                                                              => 'Bahiana',
			'"Bahianita", "regular", display'                                                                                                                                            => 'Bahianita',
			'"Bai Jamjuree", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                         => 'Bai Jamjuree',
			'"Bakbak One", "regular", display'                                                                                                                                           => 'Bakbak One',
			'"Ballet", "regular", handwriting'                                                                                                                                           => 'Ballet',
			'"Baloo 2", "regular:500:600:700:800", display'                                                                                                                              => 'Baloo 2',
			'"Baloo Bhai 2", "regular:500:600:700:800", display'                                                                                                                         => 'Baloo Bhai 2',
			'"Baloo Bhaijaan 2", "regular:500:600:700:800", display'                                                                                                                     => 'Baloo Bhaijaan 2',
			'"Baloo Bhaina 2", "regular:500:600:700:800", display'                                                                                                                       => 'Baloo Bhaina 2',
			'"Baloo Chettan 2", "regular:500:600:700:800", display'                                                                                                                      => 'Baloo Chettan 2',
			'"Baloo Da 2", "regular:500:600:700:800", display'                                                                                                                           => 'Baloo Da 2',
			'"Baloo Paaji 2", "regular:500:600:700:800", display'                                                                                                                        => 'Baloo Paaji 2',
			'"Baloo Tamma 2", "regular:500:600:700:800", display'                                                                                                                        => 'Baloo Tamma 2',
			'"Baloo Tammudu 2", "regular:500:600:700:800", display'                                                                                                                      => 'Baloo Tammudu 2',
			'"Baloo Thambi 2", "regular:500:600:700:800", display'                                                                                                                       => 'Baloo Thambi 2',
			'"Balsamiq Sans", "regular:italic:700:700italic", display'                                                                                                                   => 'Balsamiq Sans',
			'"Balthazar", "regular", serif'                                                                                                                                              => 'Balthazar',
			'"Bangers", "regular", display'                                                                                                                                              => 'Bangers',
			'"Barlow", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                     => 'Barlow',
			'"Barlow Condensed", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'           => 'Barlow Condensed',
			'"Barlow Semi Condensed", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'      => 'Barlow Semi Condensed',
			'"Barriecito", "regular", display'                                                                                                                                           => 'Barriecito',
			'"Barrio", "regular", display'                                                                                                                                               => 'Barrio',
			'"Basic", "regular", sans-serif'                                                                                                                                             => 'Basic',
			'"Baskervville", "regular:italic", serif'                                                                                                                                    => 'Baskervville',
			'"Baskervville SC", "regular", serif'                                                                                                                                        => 'Baskervville SC',
			'"Battambang", "100:300:regular:700:900", display'                                                                                                                           => 'Battambang',
			'"Baumans", "regular", display'                                                                                                                                              => 'Baumans',
			'"Bayon", "regular", sans-serif'                                                                                                                                             => 'Bayon',
			'"Be Vietnam Pro", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'             => 'Be Vietnam Pro',
			'"Beau Rivage", "regular", handwriting'                                                                                                                                      => 'Beau Rivage',
			'"Bebas Neue", "regular", sans-serif'                                                                                                                                        => 'Bebas Neue',
			'"Beiruti", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                               => 'Beiruti',
			'"Belanosima", "regular:600:700", sans-serif'                                                                                                                                => 'Belanosima',
			'"Belgrano", "regular", serif'                                                                                                                                               => 'Belgrano',
			'"Bellefair", "regular", serif'                                                                                                                                              => 'Bellefair',
			'"Belleza", "regular", sans-serif'                                                                                                                                           => 'Belleza',
			'"Bellota", "300:300italic:regular:italic:700:700italic", display'                                                                                                           => 'Bellota',
			'"Bellota Text", "300:300italic:regular:italic:700:700italic", display'                                                                                                      => 'Bellota Text',
			'"BenchNine", "300:regular:700", sans-serif'                                                                                                                                 => 'BenchNine',
			'"Benne", "regular", serif'                                                                                                                                                  => 'Benne',
			'"Bentham", "regular", serif'                                                                                                                                                => 'Bentham',
			'"Berkshire Swash", "regular", handwriting'                                                                                                                                  => 'Berkshire Swash',
			'"Besley", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                                    => 'Besley',
			'"Beth Ellen", "regular", handwriting'                                                                                                                                       => 'Beth Ellen',
			'"Bevan", "regular:italic", serif'                                                                                                                                           => 'Bevan',
			'"BhuTuka Expanded One", "regular", serif'                                                                                                                                   => 'BhuTuka Expanded One',
			'"Big Shoulders Display", "100:200:300:regular:500:600:700:800:900", display'                                                                                                => 'Big Shoulders Display',
			'"Big Shoulders Inline Display", "100:200:300:regular:500:600:700:800:900", display'                                                                                         => 'Big Shoulders Inline Display',
			'"Big Shoulders Inline Text", "100:200:300:regular:500:600:700:800:900", display'                                                                                            => 'Big Shoulders Inline Text',
			'"Big Shoulders Stencil Display", "100:200:300:regular:500:600:700:800:900", display'                                                                                        => 'Big Shoulders Stencil Display',
			'"Big Shoulders Stencil Text", "100:200:300:regular:500:600:700:800:900", display'                                                                                           => 'Big Shoulders Stencil Text',
			'"Big Shoulders Text", "100:200:300:regular:500:600:700:800:900", display'                                                                                                   => 'Big Shoulders Text',
			'"Bigelow Rules", "regular", display'                                                                                                                                        => 'Bigelow Rules',
			'"Bigshot One", "regular", display'                                                                                                                                          => 'Bigshot One',
			'"Bilbo", "regular", handwriting'                                                                                                                                            => 'Bilbo',
			'"Bilbo Swash Caps", "regular", handwriting'                                                                                                                                 => 'Bilbo Swash Caps',
			'"BioRhyme", "200:300:regular:500:600:700:800", serif'                                                                                                                       => 'BioRhyme',
			'"BioRhyme Expanded", "200:300:regular:700:800", serif'                                                                                                                      => 'BioRhyme Expanded',
			'"Birthstone", "regular", handwriting'                                                                                                                                       => 'Birthstone',
			'"Birthstone Bounce", "regular:500", handwriting'                                                                                                                            => 'Birthstone Bounce',
			'"Biryani", "200:300:regular:600:700:800:900", sans-serif'                                                                                                                   => 'Biryani',
			'"Bitter", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                          => 'Bitter',
			'"Black And White Picture", "regular", display'                                                                                                                              => 'Black And White Picture',
			'"Black Han Sans", "regular", sans-serif'                                                                                                                                    => 'Black Han Sans',
			'"Black Ops One", "regular", display'                                                                                                                                        => 'Black Ops One',
			'"Blaka", "regular", display'                                                                                                                                                => 'Blaka',
			'"Blaka Hollow", "regular", display'                                                                                                                                         => 'Blaka Hollow',
			'"Blaka Ink", "regular", display'                                                                                                                                            => 'Blaka Ink',
			'"Blinker", "100:200:300:regular:600:700:800:900", sans-serif'                                                                                                               => 'Blinker',
			'"Bodoni Moda", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                               => 'Bodoni Moda',
			'"Bodoni Moda SC", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                            => 'Bodoni Moda SC',
			'"Bokor", "regular", display'                                                                                                                                                => 'Bokor',
			'"Bona Nova", "regular:italic:700", serif'                                                                                                                                   => 'Bona Nova',
			'"Bona Nova SC", "regular:italic:700", serif'                                                                                                                                => 'Bona Nova SC',
			'"Bonbon", "regular", handwriting'                                                                                                                                           => 'Bonbon',
			'"Bonheur Royale", "regular", handwriting'                                                                                                                                   => 'Bonheur Royale',
			'"Boogaloo", "regular", display'                                                                                                                                             => 'Boogaloo',
			'"Borel", "regular", handwriting'                                                                                                                                            => 'Borel',
			'"Bowlby One", "regular", display'                                                                                                                                           => 'Bowlby One',
			'"Bowlby One SC", "regular", display'                                                                                                                                        => 'Bowlby One SC',
			'"Braah One", "regular", sans-serif'                                                                                                                                         => 'Braah One',
			'"Brawler", "regular:700", serif'                                                                                                                                            => 'Brawler',
			'"Bree Serif", "regular", serif'                                                                                                                                             => 'Bree Serif',
			'"Bricolage Grotesque", "200:300:regular:500:600:700:800", sans-serif'                                                                                                       => 'Bricolage Grotesque',
			'"Bruno Ace", "regular", display'                                                                                                                                            => 'Bruno Ace',
			'"Bruno Ace SC", "regular", display'                                                                                                                                         => 'Bruno Ace SC',
			'"Brygada 1918", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                          => 'Brygada 1918',
			'"Bubblegum Sans", "regular", display'                                                                                                                                       => 'Bubblegum Sans',
			'"Bubbler One", "regular", sans-serif'                                                                                                                                       => 'Bubbler One',
			'"Buda", "300", display'                                                                                                                                                     => 'Buda',
			'"Buenard", "regular:700", serif'                                                                                                                                            => 'Buenard',
			'"Bungee", "regular", display'                                                                                                                                               => 'Bungee',
			'"Bungee Hairline", "regular", display'                                                                                                                                      => 'Bungee Hairline',
			'"Bungee Inline", "regular", display'                                                                                                                                        => 'Bungee Inline',
			'"Bungee Outline", "regular", display'                                                                                                                                       => 'Bungee Outline',
			'"Bungee Shade", "regular", display'                                                                                                                                         => 'Bungee Shade',
			'"Bungee Spice", "regular", display'                                                                                                                                         => 'Bungee Spice',
			'"Butcherman", "regular", display'                                                                                                                                           => 'Butcherman',
			'"Butterfly Kids", "regular", handwriting'                                                                                                                                   => 'Butterfly Kids',
			'"Cabin", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                            => 'Cabin',
			'"Cabin Condensed", "regular:500:600:700", sans-serif'                                                                                                                       => 'Cabin Condensed',
			'"Cabin Sketch", "regular:700", display'                                                                                                                                     => 'Cabin Sketch',
			'"Cactus Classical Serif", "regular", serif'                                                                                                                                 => 'Cactus Classical Serif',
			'"Caesar Dressing", "regular", display'                                                                                                                                      => 'Caesar Dressing',
			'"Cagliostro", "regular", sans-serif'                                                                                                                                        => 'Cagliostro',
			'"Cairo", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                                 => 'Cairo',
			'"Cairo Play", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                            => 'Cairo Play',
			'"Caladea", "regular:italic:700:700italic", serif'                                                                                                                           => 'Caladea',
			'"Calistoga", "regular", display'                                                                                                                                            => 'Calistoga',
			'"Calligraffitti", "regular", handwriting'                                                                                                                                   => 'Calligraffitti',
			'"Cambay", "regular:italic:700:700italic", sans-serif'                                                                                                                       => 'Cambay',
			'"Cambo", "regular", serif'                                                                                                                                                  => 'Cambo',
			'"Candal", "regular", sans-serif'                                                                                                                                            => 'Candal',
			'"Cantarell", "regular:italic:700:700italic", sans-serif'                                                                                                                    => 'Cantarell',
			'"Cantata One", "regular", serif'                                                                                                                                            => 'Cantata One',
			'"Cantora One", "regular", sans-serif'                                                                                                                                       => 'Cantora One',
			'"Caprasimo", "regular", display'                                                                                                                                            => 'Caprasimo',
			'"Capriola", "regular", sans-serif'                                                                                                                                          => 'Capriola',
			'"Caramel", "regular", handwriting'                                                                                                                                          => 'Caramel',
			'"Carattere", "regular", handwriting'                                                                                                                                        => 'Carattere',
			'"Cardo", "regular:italic:700", serif'                                                                                                                                       => 'Cardo',
			'"Carlito", "regular:italic:700:700italic", sans-serif'                                                                                                                      => 'Carlito',
			'"Carme", "regular", sans-serif'                                                                                                                                             => 'Carme',
			'"Carrois Gothic", "regular", sans-serif'                                                                                                                                    => 'Carrois Gothic',
			'"Carrois Gothic SC", "regular", sans-serif'                                                                                                                                 => 'Carrois Gothic SC',
			'"Carter One", "regular", display'                                                                                                                                           => 'Carter One',
			'"Castoro", "regular:italic", serif'                                                                                                                                         => 'Castoro',
			'"Castoro Titling", "regular", display'                                                                                                                                      => 'Castoro Titling',
			'"Catamaran", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                         => 'Catamaran',
			'"Caudex", "regular:italic:700:700italic", serif'                                                                                                                            => 'Caudex',
			'"Caveat", "regular:500:600:700", handwriting'                                                                                                                               => 'Caveat',
			'"Caveat Brush", "regular", handwriting'                                                                                                                                     => 'Caveat Brush',
			'"Cedarville Cursive", "regular", handwriting'                                                                                                                               => 'Cedarville Cursive',
			'"Ceviche One", "regular", display'                                                                                                                                          => 'Ceviche One',
			'"Chakra Petch", "300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                                       => 'Chakra Petch',
			'"Changa", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                    => 'Changa',
			'"Changa One", "regular:italic", display'                                                                                                                                    => 'Changa One',
			'"Chango", "regular", display'                                                                                                                                               => 'Chango',
			'"Charis SIL", "regular:italic:700:700italic", serif'                                                                                                                        => 'Charis SIL',
			'"Charm", "regular:700", handwriting'                                                                                                                                        => 'Charm',
			'"Charmonman", "regular:700", handwriting'                                                                                                                                   => 'Charmonman',
			'"Chathura", "100:300:regular:700:800", sans-serif'                                                                                                                          => 'Chathura',
			'"Chau Philomene One", "regular:italic", sans-serif'                                                                                                                         => 'Chau Philomene One',
			'"Chela One", "regular", display'                                                                                                                                            => 'Chela One',
			'"Chelsea Market", "regular", display'                                                                                                                                       => 'Chelsea Market',
			'"Chenla", "regular", display'                                                                                                                                               => 'Chenla',
			'"Cherish", "regular", handwriting'                                                                                                                                          => 'Cherish',
			'"Cherry Bomb One", "regular", display'                                                                                                                                      => 'Cherry Bomb One',
			'"Cherry Cream Soda", "regular", display'                                                                                                                                    => 'Cherry Cream Soda',
			'"Cherry Swash", "regular:700", display'                                                                                                                                     => 'Cherry Swash',
			'"Chewy", "regular", display'                                                                                                                                                => 'Chewy',
			'"Chicle", "regular", display'                                                                                                                                               => 'Chicle',
			'"Chilanka", "regular", handwriting'                                                                                                                                         => 'Chilanka',
			'"Chivo", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                      => 'Chivo',
			'"Chivo Mono", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", monospace'                  => 'Chivo Mono',
			'"Chocolate Classical Sans", "regular", sans-serif'                                                                                                                          => 'Chocolate Classical Sans',
			'"Chokokutai", "regular", display'                                                                                                                                           => 'Chokokutai',
			'"Chonburi", "regular", display'                                                                                                                                             => 'Chonburi',
			'"Cinzel", "regular:500:600:700:800:900", serif'                                                                                                                             => 'Cinzel',
			'"Cinzel Decorative", "regular:700:900", display'                                                                                                                            => 'Cinzel Decorative',
			'"Clicker Script", "regular", handwriting'                                                                                                                                   => 'Clicker Script',
			'"Climate Crisis", "regular", display'                                                                                                                                       => 'Climate Crisis',
			'"Coda", "regular:800", display'                                                                                                                                             => 'Coda',
			'"Codystar", "300:regular", display'                                                                                                                                         => 'Codystar',
			'"Coiny", "regular", display'                                                                                                                                                => 'Coiny',
			'"Combo", "regular", display'                                                                                                                                                => 'Combo',
			'"Comfortaa", "300:regular:500:600:700", display'                                                                                                                            => 'Comfortaa',
			'"Comforter", "regular", handwriting'                                                                                                                                        => 'Comforter',
			'"Comforter Brush", "regular", handwriting'                                                                                                                                  => 'Comforter Brush',
			'"Comic Neue", "300:300italic:regular:italic:700:700italic", handwriting'                                                                                                    => 'Comic Neue',
			'"Coming Soon", "regular", handwriting'                                                                                                                                      => 'Coming Soon',
			'"Comme", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                             => 'Comme',
			'"Commissioner", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Commissioner',
			'"Concert One", "regular", display'                                                                                                                                          => 'Concert One',
			'"Condiment", "regular", handwriting'                                                                                                                                        => 'Condiment',
			'"Content", "regular:700", display'                                                                                                                                          => 'Content',
			'"Contrail One", "regular", display'                                                                                                                                         => 'Contrail One',
			'"Convergence", "regular", sans-serif'                                                                                                                                       => 'Convergence',
			'"Cookie", "regular", handwriting'                                                                                                                                           => 'Cookie',
			'"Copse", "regular", serif'                                                                                                                                                  => 'Copse',
			'"Corben", "regular:700", display'                                                                                                                                           => 'Corben',
			'"Corinthia", "regular:700", handwriting'                                                                                                                                    => 'Corinthia',
			'"Cormorant", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", serif'                                                                               => 'Cormorant',
			'"Cormorant Garamond", "300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", serif'                                                                      => 'Cormorant Garamond',
			'"Cormorant Infant", "300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", serif'                                                                        => 'Cormorant Infant',
			'"Cormorant SC", "300:regular:500:600:700", serif'                                                                                                                           => 'Cormorant SC',
			'"Cormorant Unicase", "300:regular:500:600:700", serif'                                                                                                                      => 'Cormorant Unicase',
			'"Cormorant Upright", "300:regular:500:600:700", serif'                                                                                                                      => 'Cormorant Upright',
			'"Courgette", "regular", handwriting'                                                                                                                                        => 'Courgette',
			'"Courier Prime", "regular:italic:700:700italic", monospace'                                                                                                                 => 'Courier Prime',
			'"Cousine", "regular:italic:700:700italic", monospace'                                                                                                                       => 'Cousine',
			'"Coustard", "regular:900", serif'                                                                                                                                           => 'Coustard',
			'"Covered By Your Grace", "regular", handwriting'                                                                                                                            => 'Covered By Your Grace',
			'"Crafty Girls", "regular", handwriting'                                                                                                                                     => 'Crafty Girls',
			'"Creepster", "regular", display'                                                                                                                                            => 'Creepster',
			'"Crete Round", "regular:italic", serif'                                                                                                                                     => 'Crete Round',
			'"Crimson Pro", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                                   => 'Crimson Pro',
			'"Crimson Text", "regular:italic:600:600italic:700:700italic", serif'                                                                                                        => 'Crimson Text',
			'"Croissant One", "regular", display'                                                                                                                                        => 'Croissant One',
			'"Crushed", "regular", display'                                                                                                                                              => 'Crushed',
			'"Cuprum", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                           => 'Cuprum',
			'"Cute Font", "regular", display'                                                                                                                                            => 'Cute Font',
			'"Cutive", "regular", serif'                                                                                                                                                 => 'Cutive',
			'"Cutive Mono", "regular", monospace'                                                                                                                                        => 'Cutive Mono',
			'"DM Mono", "300:300italic:regular:italic:500:500italic", monospace'                                                                                                         => 'DM Mono',
			'"DM Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'DM Sans',
			'"DM Serif Display", "regular:italic", serif'                                                                                                                                => 'DM Serif Display',
			'"DM Serif Text", "regular:italic", serif'                                                                                                                                   => 'DM Serif Text',
			'"Dai Banna SIL", "300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", serif'                                                                           => 'Dai Banna SIL',
			'"Damion", "regular", handwriting'                                                                                                                                           => 'Damion',
			'"Dancing Script", "regular:500:600:700", handwriting'                                                                                                                       => 'Dancing Script',
			'"Danfo", "regular", serif'                                                                                                                                                  => 'Danfo',
			'"Dangrek", "regular", display'                                                                                                                                              => 'Dangrek',
			'"Darker Grotesque", "300:regular:500:600:700:800:900", sans-serif'                                                                                                          => 'Darker Grotesque',
			'"Darumadrop One", "regular", display'                                                                                                                                       => 'Darumadrop One',
			'"David Libre", "regular:500:700", serif'                                                                                                                                    => 'David Libre',
			'"Dawning of a New Day", "regular", handwriting'                                                                                                                             => 'Dawning of a New Day',
			'"Days One", "regular", sans-serif'                                                                                                                                          => 'Days One',
			'"Dekko", "regular", handwriting'                                                                                                                                            => 'Dekko',
			'"Dela Gothic One", "regular", display'                                                                                                                                      => 'Dela Gothic One',
			'"Delicious Handrawn", "regular", handwriting'                                                                                                                               => 'Delicious Handrawn',
			'"Delius", "regular", handwriting'                                                                                                                                           => 'Delius',
			'"Delius Swash Caps", "regular", handwriting'                                                                                                                                => 'Delius Swash Caps',
			'"Delius Unicase", "regular:700", handwriting'                                                                                                                               => 'Delius Unicase',
			'"Della Respira", "regular", serif'                                                                                                                                          => 'Della Respira',
			'"Denk One", "regular", sans-serif'                                                                                                                                          => 'Denk One',
			'"Devonshire", "regular", handwriting'                                                                                                                                       => 'Devonshire',
			'"Dhurjati", "regular", sans-serif'                                                                                                                                          => 'Dhurjati',
			'"Didact Gothic", "regular", sans-serif'                                                                                                                                     => 'Didact Gothic',
			'"Diphylleia", "regular", serif'                                                                                                                                             => 'Diphylleia',
			'"Diplomata", "regular", display'                                                                                                                                            => 'Diplomata',
			'"Diplomata SC", "regular", display'                                                                                                                                         => 'Diplomata SC',
			'"Do Hyeon", "regular", sans-serif'                                                                                                                                          => 'Do Hyeon',
			'"Dokdo", "regular", display'                                                                                                                                                => 'Dokdo',
			'"Domine", "regular:500:600:700", serif'                                                                                                                                     => 'Domine',
			'"Donegal One", "regular", serif'                                                                                                                                            => 'Donegal One',
			'"Dongle", "300:regular:700", sans-serif'                                                                                                                                    => 'Dongle',
			'"Doppio One", "regular", sans-serif'                                                                                                                                        => 'Doppio One',
			'"Dorsa", "regular", sans-serif'                                                                                                                                             => 'Dorsa',
			'"Dosis", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                     => 'Dosis',
			'"DotGothic16", "regular", sans-serif'                                                                                                                                       => 'DotGothic16',
			'"Dr Sugiyama", "regular", handwriting'                                                                                                                                      => 'Dr Sugiyama',
			'"Duru Sans", "regular", sans-serif'                                                                                                                                         => 'Duru Sans',
			'"DynaPuff", "regular:500:600:700", display'                                                                                                                                 => 'DynaPuff',
			'"Dynalight", "regular", display'                                                                                                                                            => 'Dynalight',
			'"EB Garamond", "regular:500:600:700:800:italic:500italic:600italic:700italic:800italic", serif'                                                                             => 'EB Garamond',
			'"Eagle Lake", "regular", handwriting'                                                                                                                                       => 'Eagle Lake',
			'"East Sea Dokdo", "regular", handwriting'                                                                                                                                   => 'East Sea Dokdo',
			'"Eater", "regular", display'                                                                                                                                                => 'Eater',
			'"Economica", "regular:italic:700:700italic", sans-serif'                                                                                                                    => 'Economica',
			'"Eczar", "regular:500:600:700:800", serif'                                                                                                                                  => 'Eczar',
			'"Edu AU VIC WA NT Hand", "regular:500:600:700", handwriting'                                                                                                                => 'Edu AU VIC WA NT Hand',
			'"Edu NSW ACT Foundation", "regular:500:600:700", handwriting'                                                                                                               => 'Edu NSW ACT Foundation',
			'"Edu QLD Beginner", "regular:500:600:700", handwriting'                                                                                                                     => 'Edu QLD Beginner',
			'"Edu SA Beginner", "regular:500:600:700", handwriting'                                                                                                                      => 'Edu SA Beginner',
			'"Edu TAS Beginner", "regular:500:600:700", handwriting'                                                                                                                     => 'Edu TAS Beginner',
			'"Edu VIC WA NT Beginner", "regular:500:600:700", handwriting'                                                                                                               => 'Edu VIC WA NT Beginner',
			'"El Messiri", "regular:500:600:700", sans-serif'                                                                                                                            => 'El Messiri',
			'"Electrolize", "regular", sans-serif'                                                                                                                                       => 'Electrolize',
			'"Elsie", "regular:900", display'                                                                                                                                            => 'Elsie',
			'"Elsie Swash Caps", "regular:900", display'                                                                                                                                 => 'Elsie Swash Caps',
			'"Emblema One", "regular", display'                                                                                                                                          => 'Emblema One',
			'"Emilys Candy", "regular", display'                                                                                                                                         => 'Emilys Candy',
			'"Encode Sans", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Encode Sans',
			'"Encode Sans Condensed", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                             => 'Encode Sans Condensed',
			'"Encode Sans Expanded", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                              => 'Encode Sans Expanded',
			'"Encode Sans SC", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                    => 'Encode Sans SC',
			'"Encode Sans Semi Condensed", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                        => 'Encode Sans Semi Condensed',
			'"Encode Sans Semi Expanded", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                         => 'Encode Sans Semi Expanded',
			'"Engagement", "regular", handwriting'                                                                                                                                       => 'Engagement',
			'"Englebert", "regular", sans-serif'                                                                                                                                         => 'Englebert',
			'"Enriqueta", "regular:500:600:700", serif'                                                                                                                                  => 'Enriqueta',
			'"Ephesis", "regular", handwriting'                                                                                                                                          => 'Ephesis',
			'"Epilogue", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                   => 'Epilogue',
			'"Erica One", "regular", display'                                                                                                                                            => 'Erica One',
			'"Esteban", "regular", serif'                                                                                                                                                => 'Esteban',
			'"Estonia", "regular", handwriting'                                                                                                                                          => 'Estonia',
			'"Euphoria Script", "regular", handwriting'                                                                                                                                  => 'Euphoria Script',
			'"Ewert", "regular", display'                                                                                                                                                => 'Ewert',
			'"Exo", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                        => 'Exo',
			'"Exo 2", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                      => 'Exo 2',
			'"Expletus Sans", "regular:500:600:700:italic:500italic:600italic:700italic", display'                                                                                       => 'Expletus Sans',
			'"Explora", "regular", handwriting'                                                                                                                                          => 'Explora',
			'"Fahkwang", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                             => 'Fahkwang',
			'"Familjen Grotesk", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                 => 'Familjen Grotesk',
			'"Fanwood Text", "regular:italic", serif'                                                                                                                                    => 'Fanwood Text',
			'"Farro", "300:regular:500:700", sans-serif'                                                                                                                                 => 'Farro',
			'"Farsan", "regular", display'                                                                                                                                               => 'Farsan',
			'"Fascinate", "regular", display'                                                                                                                                            => 'Fascinate',
			'"Fascinate Inline", "regular", display'                                                                                                                                     => 'Fascinate Inline',
			'"Faster One", "regular", display'                                                                                                                                           => 'Faster One',
			'"Fasthand", "regular", display'                                                                                                                                             => 'Fasthand',
			'"Fauna One", "regular", serif'                                                                                                                                              => 'Fauna One',
			'"Faustina", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", serif'                                                                  => 'Faustina',
			'"Federant", "regular", display'                                                                                                                                             => 'Federant',
			'"Federo", "regular", sans-serif'                                                                                                                                            => 'Federo',
			'"Felipa", "regular", handwriting'                                                                                                                                           => 'Felipa',
			'"Fenix", "regular", serif'                                                                                                                                                  => 'Fenix',
			'"Festive", "regular", handwriting'                                                                                                                                          => 'Festive',
			'"Figtree", "300:regular:500:600:700:800:900:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                                => 'Figtree',
			'"Finger Paint", "regular", display'                                                                                                                                         => 'Finger Paint',
			'"Finlandica", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                       => 'Finlandica',
			'"Fira Code", "300:regular:500:600:700", monospace'                                                                                                                          => 'Fira Code',
			'"Fira Mono", "regular:500:700", monospace'                                                                                                                                  => 'Fira Mono',
			'"Fira Sans", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                  => 'Fira Sans',
			'"Fira Sans Condensed", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'        => 'Fira Sans Condensed',
			'"Fira Sans Extra Condensed", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'  => 'Fira Sans Extra Condensed',
			'"Fjalla One", "regular", sans-serif'                                                                                                                                        => 'Fjalla One',
			'"Fjord One", "regular", serif'                                                                                                                                              => 'Fjord One',
			'"Flamenco", "300:regular", display'                                                                                                                                         => 'Flamenco',
			'"Flavors", "regular", display'                                                                                                                                              => 'Flavors',
			'"Fleur De Leah", "regular", handwriting'                                                                                                                                    => 'Fleur De Leah',
			'"Flow Block", "regular", display'                                                                                                                                           => 'Flow Block',
			'"Flow Circular", "regular", display'                                                                                                                                        => 'Flow Circular',
			'"Flow Rounded", "regular", display'                                                                                                                                         => 'Flow Rounded',
			'"Foldit", "100:200:300:regular:500:600:700:800:900", display'                                                                                                               => 'Foldit',
			'"Fondamento", "regular:italic", handwriting'                                                                                                                                => 'Fondamento',
			'"Fontdiner Swanky", "regular", display'                                                                                                                                     => 'Fontdiner Swanky',
			'"Forum", "regular", display'                                                                                                                                                => 'Forum',
			'"Fragment Mono", "regular:italic", monospace'                                                                                                                               => 'Fragment Mono',
			'"Francois One", "regular", sans-serif'                                                                                                                                      => 'Francois One',
			'"Frank Ruhl Libre", "300:regular:500:600:700:800:900", serif'                                                                                                               => 'Frank Ruhl Libre',
			'"Fraunces", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                        => 'Fraunces',
			'"Freckle Face", "regular", display'                                                                                                                                         => 'Freckle Face',
			'"Fredericka the Great", "regular", display'                                                                                                                                 => 'Fredericka the Great',
			'"Fredoka", "300:regular:500:600:700", sans-serif'                                                                                                                           => 'Fredoka',
			'"Freehand", "regular", display'                                                                                                                                             => 'Freehand',
			'"Freeman", "regular", display'                                                                                                                                              => 'Freeman',
			'"Fresca", "regular", sans-serif'                                                                                                                                            => 'Fresca',
			'"Frijole", "regular", display'                                                                                                                                              => 'Frijole',
			'"Fruktur", "regular:italic", display'                                                                                                                                       => 'Fruktur',
			'"Fugaz One", "regular", display'                                                                                                                                            => 'Fugaz One',
			'"Fuggles", "regular", handwriting'                                                                                                                                          => 'Fuggles',
			'"Fustat", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                    => 'Fustat',
			'"Fuzzy Bubbles", "regular:700", handwriting'                                                                                                                                => 'Fuzzy Bubbles',
			'"GFS Didot", "regular", serif'                                                                                                                                              => 'GFS Didot',
			'"GFS Neohellenic", "regular:italic:700:700italic", sans-serif'                                                                                                              => 'GFS Neohellenic',
			'"Ga Maamli", "regular", display'                                                                                                                                            => 'Ga Maamli',
			'"Gabarito", "regular:500:600:700:800:900", display'                                                                                                                         => 'Gabarito',
			'"Gabriela", "regular", serif'                                                                                                                                               => 'Gabriela',
			'"Gaegu", "300:regular:700", handwriting'                                                                                                                                    => 'Gaegu',
			'"Gafata", "regular", sans-serif'                                                                                                                                            => 'Gafata',
			'"Gajraj One", "regular", display'                                                                                                                                           => 'Gajraj One',
			'"Galada", "regular", display'                                                                                                                                               => 'Galada',
			'"Galdeano", "regular", sans-serif'                                                                                                                                          => 'Galdeano',
			'"Galindo", "regular", display'                                                                                                                                              => 'Galindo',
			'"Gamja Flower", "regular", handwriting'                                                                                                                                     => 'Gamja Flower',
			'"Gantari", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'Gantari',
			'"Gasoek One", "regular", sans-serif'                                                                                                                                        => 'Gasoek One',
			'"Gayathri", "100:regular:700", sans-serif'                                                                                                                                  => 'Gayathri',
			'"Gelasio", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                               => 'Gelasio',
			'"Gemunu Libre", "200:300:regular:500:600:700:800", sans-serif'                                                                                                              => 'Gemunu Libre',
			'"Genos", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                      => 'Genos',
			'"Gentium Book Plus", "regular:italic:700:700italic", serif'                                                                                                                 => 'Gentium Book Plus',
			'"Gentium Plus", "regular:italic:700:700italic", serif'                                                                                                                      => 'Gentium Plus',
			'"Geo", "regular:italic", sans-serif'                                                                                                                                        => 'Geo',
			'"Geologica", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                         => 'Geologica',
			'"Georama", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'Georama',
			'"Geostar", "regular", display'                                                                                                                                              => 'Geostar',
			'"Geostar Fill", "regular", display'                                                                                                                                         => 'Geostar Fill',
			'"Germania One", "regular", display'                                                                                                                                         => 'Germania One',
			'"Gideon Roman", "regular", display'                                                                                                                                         => 'Gideon Roman',
			'"Gidugu", "regular", sans-serif'                                                                                                                                            => 'Gidugu',
			'"Gilda Display", "regular", serif'                                                                                                                                          => 'Gilda Display',
			'"Girassol", "regular", display'                                                                                                                                             => 'Girassol',
			'"Give You Glory", "regular", handwriting'                                                                                                                                   => 'Give You Glory',
			'"Glass Antiqua", "regular", display'                                                                                                                                        => 'Glass Antiqua',
			'"Glegoo", "regular:700", serif'                                                                                                                                             => 'Glegoo',
			'"Gloock", "regular", serif'                                                                                                                                                 => 'Gloock',
			'"Gloria Hallelujah", "regular", handwriting'                                                                                                                                => 'Gloria Hallelujah',
			'"Glory", "100:200:300:regular:500:600:700:800:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                                    => 'Glory',
			'"Gluten", "100:200:300:regular:500:600:700:800:900", display'                                                                                                               => 'Gluten',
			'"Goblin One", "regular", display'                                                                                                                                           => 'Goblin One',
			'"Gochi Hand", "regular", handwriting'                                                                                                                                       => 'Gochi Hand',
			'"Goldman", "regular:700", display'                                                                                                                                          => 'Goldman',
			'"Golos Text", "regular:500:600:700:800:900", sans-serif'                                                                                                                    => 'Golos Text',
			'"Gorditas", "regular:700", display'                                                                                                                                         => 'Gorditas',
			'"Gothic A1", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                         => 'Gothic A1',
			'"Gotu", "regular", sans-serif'                                                                                                                                              => 'Gotu',
			'"Goudy Bookletter 1911", "regular", serif'                                                                                                                                  => 'Goudy Bookletter 1911',
			'"Gowun Batang", "regular:700", serif'                                                                                                                                       => 'Gowun Batang',
			'"Gowun Dodum", "regular", sans-serif'                                                                                                                                       => 'Gowun Dodum',
			'"Graduate", "regular", serif'                                                                                                                                               => 'Graduate',
			'"Grand Hotel", "regular", handwriting'                                                                                                                                      => 'Grand Hotel',
			'"Grandiflora One", "regular", serif'                                                                                                                                        => 'Grandiflora One',
			'"Grandstander", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", display'                  => 'Grandstander',
			'"Grape Nuts", "regular", handwriting'                                                                                                                                       => 'Grape Nuts',
			'"Gravitas One", "regular", display'                                                                                                                                         => 'Gravitas One',
			'"Great Vibes", "regular", handwriting'                                                                                                                                      => 'Great Vibes',
			'"Grechen Fuemen", "regular", handwriting'                                                                                                                                   => 'Grechen Fuemen',
			'"Grenze", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", serif'                          => 'Grenze',
			'"Grenze Gotisch", "100:200:300:regular:500:600:700:800:900", display'                                                                                                       => 'Grenze Gotisch',
			'"Grey Qo", "regular", handwriting'                                                                                                                                          => 'Grey Qo',
			'"Griffy", "regular", display'                                                                                                                                               => 'Griffy',
			'"Gruppo", "regular", sans-serif'                                                                                                                                            => 'Gruppo',
			'"Gudea", "regular:italic:700", sans-serif'                                                                                                                                  => 'Gudea',
			'"Gugi", "regular", display'                                                                                                                                                 => 'Gugi',
			'"Gulzar", "regular", serif'                                                                                                                                                 => 'Gulzar',
			'"Gupter", "regular:500:700", serif'                                                                                                                                         => 'Gupter',
			'"Gurajada", "regular", serif'                                                                                                                                               => 'Gurajada',
			'"Gwendolyn", "regular:700", handwriting'                                                                                                                                    => 'Gwendolyn',
			'"Habibi", "regular", serif'                                                                                                                                                 => 'Habibi',
			'"Hachi Maru Pop", "regular", handwriting'                                                                                                                                   => 'Hachi Maru Pop',
			'"Hahmlet", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                                => 'Hahmlet',
			'"Halant", "300:regular:500:600:700", serif'                                                                                                                                 => 'Halant',
			'"Hammersmith One", "regular", sans-serif'                                                                                                                                   => 'Hammersmith One',
			'"Hanalei", "regular", display'                                                                                                                                              => 'Hanalei',
			'"Hanalei Fill", "regular", display'                                                                                                                                         => 'Hanalei Fill',
			'"Handjet", "100:200:300:regular:500:600:700:800:900", display'                                                                                                              => 'Handjet',
			'"Handlee", "regular", handwriting'                                                                                                                                          => 'Handlee',
			'"Hanken Grotesk", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'             => 'Hanken Grotesk',
			'"Hanuman", "100:300:regular:700:900", serif'                                                                                                                                => 'Hanuman',
			'"Happy Monkey", "regular", display'                                                                                                                                         => 'Happy Monkey',
			'"Harmattan", "regular:500:600:700", sans-serif'                                                                                                                             => 'Harmattan',
			'"Headland One", "regular", serif'                                                                                                                                           => 'Headland One',
			'"Hedvig Letters Sans", "regular", sans-serif'                                                                                                                               => 'Hedvig Letters Sans',
			'"Hedvig Letters Serif", "regular", serif'                                                                                                                                   => 'Hedvig Letters Serif',
			'"Heebo", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                             => 'Heebo',
			'"Henny Penny", "regular", display'                                                                                                                                          => 'Henny Penny',
			'"Hepta Slab", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                             => 'Hepta Slab',
			'"Herr Von Muellerhoff", "regular", handwriting'                                                                                                                             => 'Herr Von Muellerhoff',
			'"Hi Melody", "regular", handwriting'                                                                                                                                        => 'Hi Melody',
			'"Hina Mincho", "regular", serif'                                                                                                                                            => 'Hina Mincho',
			'"Hind", "300:regular:500:600:700", sans-serif'                                                                                                                              => 'Hind',
			'"Hind Guntur", "300:regular:500:600:700", sans-serif'                                                                                                                       => 'Hind Guntur',
			'"Hind Madurai", "300:regular:500:600:700", sans-serif'                                                                                                                      => 'Hind Madurai',
			'"Hind Siliguri", "300:regular:500:600:700", sans-serif'                                                                                                                     => 'Hind Siliguri',
			'"Hind Vadodara", "300:regular:500:600:700", sans-serif'                                                                                                                     => 'Hind Vadodara',
			'"Holtwood One SC", "regular", serif'                                                                                                                                        => 'Holtwood One SC',
			'"Homemade Apple", "regular", handwriting'                                                                                                                                   => 'Homemade Apple',
			'"Homenaje", "regular", sans-serif'                                                                                                                                          => 'Homenaje',
			'"Honk", "regular", display'                                                                                                                                                 => 'Honk',
			'"Hubballi", "regular", sans-serif'                                                                                                                                          => 'Hubballi',
			'"Hurricane", "regular", handwriting'                                                                                                                                        => 'Hurricane',
			'"IBM Plex Mono", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", monospace'                                           => 'IBM Plex Mono',
			'"IBM Plex Sans", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                          => 'IBM Plex Sans',
			'"IBM Plex Sans Arabic", "100:200:300:regular:500:600:700", sans-serif'                                                                                                      => 'IBM Plex Sans Arabic',
			'"IBM Plex Sans Condensed", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                => 'IBM Plex Sans Condensed',
			'"IBM Plex Sans Devanagari", "100:200:300:regular:500:600:700", sans-serif'                                                                                                  => 'IBM Plex Sans Devanagari',
			'"IBM Plex Sans Hebrew", "100:200:300:regular:500:600:700", sans-serif'                                                                                                      => 'IBM Plex Sans Hebrew',
			'"IBM Plex Sans JP", "100:200:300:regular:500:600:700", sans-serif'                                                                                                          => 'IBM Plex Sans JP',
			'"IBM Plex Sans KR", "100:200:300:regular:500:600:700", sans-serif'                                                                                                          => 'IBM Plex Sans KR',
			'"IBM Plex Sans Thai", "100:200:300:regular:500:600:700", sans-serif'                                                                                                        => 'IBM Plex Sans Thai',
			'"IBM Plex Sans Thai Looped", "100:200:300:regular:500:600:700", sans-serif'                                                                                                 => 'IBM Plex Sans Thai Looped',
			'"IBM Plex Serif", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", serif'                                              => 'IBM Plex Serif',
			'"IM Fell DW Pica", "regular:italic", serif'                                                                                                                                 => 'IM Fell DW Pica',
			'"IM Fell DW Pica SC", "regular", serif'                                                                                                                                     => 'IM Fell DW Pica SC',
			'"IM Fell Double Pica", "regular:italic", serif'                                                                                                                             => 'IM Fell Double Pica',
			'"IM Fell Double Pica SC", "regular", serif'                                                                                                                                 => 'IM Fell Double Pica SC',
			'"IM Fell English", "regular:italic", serif'                                                                                                                                 => 'IM Fell English',
			'"IM Fell English SC", "regular", serif'                                                                                                                                     => 'IM Fell English SC',
			'"IM Fell French Canon", "regular:italic", serif'                                                                                                                            => 'IM Fell French Canon',
			'"IM Fell French Canon SC", "regular", serif'                                                                                                                                => 'IM Fell French Canon SC',
			'"IM Fell Great Primer", "regular:italic", serif'                                                                                                                            => 'IM Fell Great Primer',
			'"IM Fell Great Primer SC", "regular", serif'                                                                                                                                => 'IM Fell Great Primer SC',
			'"Ibarra Real Nova", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                      => 'Ibarra Real Nova',
			'"Iceberg", "regular", display'                                                                                                                                              => 'Iceberg',
			'"Iceland", "regular", display'                                                                                                                                              => 'Iceland',
			'"Imbue", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                                  => 'Imbue',
			'"Imperial Script", "regular", handwriting'                                                                                                                                  => 'Imperial Script',
			'"Imprima", "regular", sans-serif'                                                                                                                                           => 'Imprima',
			'"Inclusive Sans", "regular:italic", sans-serif'                                                                                                                             => 'Inclusive Sans',
			'"Inconsolata", "200:300:regular:500:600:700:800:900", monospace'                                                                                                            => 'Inconsolata',
			'"Inder", "regular", sans-serif'                                                                                                                                             => 'Inder',
			'"Indie Flower", "regular", handwriting'                                                                                                                                     => 'Indie Flower',
			'"Ingrid Darling", "regular", handwriting'                                                                                                                                   => 'Ingrid Darling',
			'"Inika", "regular:700", serif'                                                                                                                                              => 'Inika',
			'"Inknut Antiqua", "300:regular:500:600:700:800:900", serif'                                                                                                                 => 'Inknut Antiqua',
			'"Inria Sans", "300:300italic:regular:italic:700:700italic", sans-serif'                                                                                                     => 'Inria Sans',
			'"Inria Serif", "300:300italic:regular:italic:700:700italic", serif'                                                                                                         => 'Inria Serif',
			'"Inspiration", "regular", handwriting'                                                                                                                                      => 'Inspiration',
			'"Instrument Sans", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                  => 'Instrument Sans',
			'"Instrument Serif", "regular:italic", serif'                                                                                                                                => 'Instrument Serif',
			'"Inter", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                      => 'Inter',
			'"Inter Tight", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                => 'Inter Tight',
			'"Irish Grover", "regular", display'                                                                                                                                         => 'Irish Grover',
			'"Island Moments", "regular", handwriting'                                                                                                                                   => 'Island Moments',
			'"Istok Web", "regular:italic:700:700italic", sans-serif'                                                                                                                    => 'Istok Web',
			'"Italiana", "regular", serif'                                                                                                                                               => 'Italiana',
			'"Italianno", "regular", handwriting'                                                                                                                                        => 'Italianno',
			'"Itim", "regular", handwriting'                                                                                                                                             => 'Itim',
			'"Jacquard 12", "regular", display'                                                                                                                                          => 'Jacquard 12',
			'"Jacquard 12 Charted", "regular", display'                                                                                                                                  => 'Jacquard 12 Charted',
			'"Jacquard 24", "regular", display'                                                                                                                                          => 'Jacquard 24',
			'"Jacquard 24 Charted", "regular", display'                                                                                                                                  => 'Jacquard 24 Charted',
			'"Jacquarda Bastarda 9", "regular", display'                                                                                                                                 => 'Jacquarda Bastarda 9',
			'"Jacquarda Bastarda 9 Charted", "regular", display'                                                                                                                         => 'Jacquarda Bastarda 9 Charted',
			'"Jacques Francois", "regular", serif'                                                                                                                                       => 'Jacques Francois',
			'"Jacques Francois Shadow", "regular", display'                                                                                                                              => 'Jacques Francois Shadow',
			'"Jaini", "regular", display'                                                                                                                                                => 'Jaini',
			'"Jaini Purva", "regular", display'                                                                                                                                          => 'Jaini Purva',
			'"Jaldi", "regular:700", sans-serif'                                                                                                                                         => 'Jaldi',
			'"Jaro", "regular", sans-serif'                                                                                                                                              => 'Jaro',
			'"Jersey 10", "regular", display'                                                                                                                                            => 'Jersey 10',
			'"Jersey 10 Charted", "regular", display'                                                                                                                                    => 'Jersey 10 Charted',
			'"Jersey 15", "regular", display'                                                                                                                                            => 'Jersey 15',
			'"Jersey 15 Charted", "regular", display'                                                                                                                                    => 'Jersey 15 Charted',
			'"Jersey 20", "regular", display'                                                                                                                                            => 'Jersey 20',
			'"Jersey 20 Charted", "regular", display'                                                                                                                                    => 'Jersey 20 Charted',
			'"Jersey 25", "regular", display'                                                                                                                                            => 'Jersey 25',
			'"Jersey 25 Charted", "regular", display'                                                                                                                                    => 'Jersey 25 Charted',
			'"JetBrains Mono", "100:200:300:regular:500:600:700:800:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic", monospace'                            => 'JetBrains Mono',
			'"Jim Nightshade", "regular", handwriting'                                                                                                                                   => 'Jim Nightshade',
			'"Joan", "regular", serif'                                                                                                                                                   => 'Joan',
			'"Jockey One", "regular", sans-serif'                                                                                                                                        => 'Jockey One',
			'"Jolly Lodger", "regular", display'                                                                                                                                         => 'Jolly Lodger',
			'"Jomhuria", "regular", display'                                                                                                                                             => 'Jomhuria',
			'"Jomolhari", "regular", serif'                                                                                                                                              => 'Jomolhari',
			'"Josefin Sans", "100:200:300:regular:500:600:700:100italic:200italic:300italic:italic:500italic:600italic:700italic", sans-serif'                                           => 'Josefin Sans',
			'"Josefin Slab", "100:200:300:regular:500:600:700:100italic:200italic:300italic:italic:500italic:600italic:700italic", serif'                                                => 'Josefin Slab',
			'"Jost", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                       => 'Jost',
			'"Joti One", "regular", display'                                                                                                                                             => 'Joti One',
			'"Jua", "regular", sans-serif'                                                                                                                                               => 'Jua',
			'"Judson", "regular:italic:700", serif'                                                                                                                                      => 'Judson',
			'"Julee", "regular", handwriting'                                                                                                                                            => 'Julee',
			'"Julius Sans One", "regular", sans-serif'                                                                                                                                   => 'Julius Sans One',
			'"Junge", "regular", serif'                                                                                                                                                  => 'Junge',
			'"Jura", "300:regular:500:600:700", sans-serif'                                                                                                                              => 'Jura',
			'"Just Another Hand", "regular", handwriting'                                                                                                                                => 'Just Another Hand',
			'"Just Me Again Down Here", "regular", handwriting'                                                                                                                          => 'Just Me Again Down Here',
			'"K2D", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", sans-serif'                                      => 'K2D',
			'"Kablammo", "regular", display'                                                                                                                                             => 'Kablammo',
			'"Kadwa", "regular:700", serif'                                                                                                                                              => 'Kadwa',
			'"Kaisei Decol", "regular:500:700", serif'                                                                                                                                   => 'Kaisei Decol',
			'"Kaisei HarunoUmi", "regular:500:700", serif'                                                                                                                               => 'Kaisei HarunoUmi',
			'"Kaisei Opti", "regular:500:700", serif'                                                                                                                                    => 'Kaisei Opti',
			'"Kaisei Tokumin", "regular:500:700:800", serif'                                                                                                                             => 'Kaisei Tokumin',
			'"Kalam", "300:regular:700", handwriting'                                                                                                                                    => 'Kalam',
			'"Kalnia", "100:200:300:regular:500:600:700", serif'                                                                                                                         => 'Kalnia',
			'"Kalnia Glaze", "100:200:300:regular:500:600:700", display'                                                                                                                 => 'Kalnia Glaze',
			'"Kameron", "regular:500:600:700", serif'                                                                                                                                    => 'Kameron',
			'"Kanit", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                      => 'Kanit',
			'"Kantumruy Pro", "100:200:300:regular:500:600:700:100italic:200italic:300italic:italic:500italic:600italic:700italic", sans-serif'                                          => 'Kantumruy Pro',
			'"Karantina", "300:regular:700", display'                                                                                                                                    => 'Karantina',
			'"Karla", "200:300:regular:500:600:700:800:200italic:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                                                  => 'Karla',
			'"Karma", "300:regular:500:600:700", serif'                                                                                                                                  => 'Karma',
			'"Katibeh", "regular", display'                                                                                                                                              => 'Katibeh',
			'"Kaushan Script", "regular", handwriting'                                                                                                                                   => 'Kaushan Script',
			'"Kavivanar", "regular", handwriting'                                                                                                                                        => 'Kavivanar',
			'"Kavoon", "regular", display'                                                                                                                                               => 'Kavoon',
			'"Kay Pho Du", "regular:500:600:700", serif'                                                                                                                                 => 'Kay Pho Du',
			'"Kdam Thmor Pro", "regular", sans-serif'                                                                                                                                    => 'Kdam Thmor Pro',
			'"Keania One", "regular", display'                                                                                                                                           => 'Keania One',
			'"Kelly Slab", "regular", display'                                                                                                                                           => 'Kelly Slab',
			'"Kenia", "regular", display'                                                                                                                                                => 'Kenia',
			'"Khand", "300:regular:500:600:700", sans-serif'                                                                                                                             => 'Khand',
			'"Khmer", "regular", sans-serif'                                                                                                                                             => 'Khmer',
			'"Khula", "300:regular:600:700:800", sans-serif'                                                                                                                             => 'Khula',
			'"Kings", "regular", handwriting'                                                                                                                                            => 'Kings',
			'"Kirang Haerang", "regular", display'                                                                                                                                       => 'Kirang Haerang',
			'"Kite One", "regular", sans-serif'                                                                                                                                          => 'Kite One',
			'"Kiwi Maru", "300:regular:500", serif'                                                                                                                                      => 'Kiwi Maru',
			'"Klee One", "regular:600", handwriting'                                                                                                                                     => 'Klee One',
			'"Knewave", "regular", display'                                                                                                                                              => 'Knewave',
			'"KoHo", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                                 => 'KoHo',
			'"Kodchasan", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                            => 'Kodchasan',
			'"Kode Mono", "regular:500:600:700", monospace'                                                                                                                              => 'Kode Mono',
			'"Koh Santepheap", "100:300:regular:700:900", serif'                                                                                                                         => 'Koh Santepheap',
			'"Kolker Brush", "regular", handwriting'                                                                                                                                     => 'Kolker Brush',
			'"Konkhmer Sleokchher", "regular", display'                                                                                                                                  => 'Konkhmer Sleokchher',
			'"Kosugi", "regular", sans-serif'                                                                                                                                            => 'Kosugi',
			'"Kosugi Maru", "regular", sans-serif'                                                                                                                                       => 'Kosugi Maru',
			'"Kotta One", "regular", serif'                                                                                                                                              => 'Kotta One',
			'"Koulen", "regular", display'                                                                                                                                               => 'Koulen',
			'"Kranky", "regular", display'                                                                                                                                               => 'Kranky',
			'"Kreon", "300:regular:500:600:700", serif'                                                                                                                                  => 'Kreon',
			'"Kristi", "regular", handwriting'                                                                                                                                           => 'Kristi',
			'"Krona One", "regular", sans-serif'                                                                                                                                         => 'Krona One',
			'"Krub", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                                 => 'Krub',
			'"Kufam", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                                                => 'Kufam',
			'"Kulim Park", "200:200italic:300:300italic:regular:italic:600:600italic:700:700italic", sans-serif'                                                                         => 'Kulim Park',
			'"Kumar One", "regular", display'                                                                                                                                            => 'Kumar One',
			'"Kumar One Outline", "regular", display'                                                                                                                                    => 'Kumar One Outline',
			'"Kumbh Sans", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                        => 'Kumbh Sans',
			'"Kurale", "regular", serif'                                                                                                                                                 => 'Kurale',
			'"LXGW WenKai Mono TC", "300:regular:700", monospace'                                                                                                                        => 'LXGW WenKai Mono TC',
			'"LXGW WenKai TC", "300:regular:700", handwriting'                                                                                                                           => 'LXGW WenKai TC',
			'"La Belle Aurore", "regular", handwriting'                                                                                                                                  => 'La Belle Aurore',
			'"Labrada", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                         => 'Labrada',
			'"Lacquer", "regular", display'                                                                                                                                              => 'Lacquer',
			'"Laila", "300:regular:500:600:700", sans-serif'                                                                                                                             => 'Laila',
			'"Lakki Reddy", "regular", handwriting'                                                                                                                                      => 'Lakki Reddy',
			'"Lalezar", "regular", display'                                                                                                                                              => 'Lalezar',
			'"Lancelot", "regular", display'                                                                                                                                             => 'Lancelot',
			'"Langar", "regular", display'                                                                                                                                               => 'Langar',
			'"Lateef", "200:300:regular:500:600:700:800", serif'                                                                                                                         => 'Lateef',
			'"Lato", "100:100italic:300:300italic:regular:italic:700:700italic:900:900italic", sans-serif'                                                                               => 'Lato',
			'"Lavishly Yours", "regular", handwriting'                                                                                                                                   => 'Lavishly Yours',
			'"League Gothic", "regular", sans-serif'                                                                                                                                     => 'League Gothic',
			'"League Script", "regular", handwriting'                                                                                                                                    => 'League Script',
			'"League Spartan", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                    => 'League Spartan',
			'"Leckerli One", "regular", handwriting'                                                                                                                                     => 'Leckerli One',
			'"Ledger", "regular", serif'                                                                                                                                                 => 'Ledger',
			'"Lekton", "regular:italic:700", monospace'                                                                                                                                  => 'Lekton',
			'"Lemon", "regular", display'                                                                                                                                                => 'Lemon',
			'"Lemonada", "300:regular:500:600:700", display'                                                                                                                             => 'Lemonada',
			'"Lexend", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                            => 'Lexend',
			'"Lexend Deca", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Lexend Deca',
			'"Lexend Exa", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                        => 'Lexend Exa',
			'"Lexend Giga", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Lexend Giga',
			'"Lexend Mega", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Lexend Mega',
			'"Lexend Peta", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Lexend Peta',
			'"Lexend Tera", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Lexend Tera',
			'"Lexend Zetta", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Lexend Zetta',
			'"Libre Barcode 128", "regular", display'                                                                                                                                    => 'Libre Barcode 128',
			'"Libre Barcode 128 Text", "regular", display'                                                                                                                               => 'Libre Barcode 128 Text',
			'"Libre Barcode 39", "regular", display'                                                                                                                                     => 'Libre Barcode 39',
			'"Libre Barcode 39 Extended", "regular", display'                                                                                                                            => 'Libre Barcode 39 Extended',
			'"Libre Barcode 39 Extended Text", "regular", display'                                                                                                                       => 'Libre Barcode 39 Extended Text',
			'"Libre Barcode 39 Text", "regular", display'                                                                                                                                => 'Libre Barcode 39 Text',
			'"Libre Barcode EAN13 Text", "regular", display'                                                                                                                             => 'Libre Barcode EAN13 Text',
			'"Libre Baskerville", "regular:italic:700", serif'                                                                                                                           => 'Libre Baskerville',
			'"Libre Bodoni", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                          => 'Libre Bodoni',
			'"Libre Caslon Display", "regular", serif'                                                                                                                                   => 'Libre Caslon Display',
			'"Libre Caslon Text", "regular:italic:700", serif'                                                                                                                           => 'Libre Caslon Text',
			'"Libre Franklin", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'             => 'Libre Franklin',
			'"Licorice", "regular", handwriting'                                                                                                                                         => 'Licorice',
			'"Life Savers", "regular:700:800", display'                                                                                                                                  => 'Life Savers',
			'"Lilita One", "regular", display'                                                                                                                                           => 'Lilita One',
			'"Lily Script One", "regular", display'                                                                                                                                      => 'Lily Script One',
			'"Limelight", "regular", display'                                                                                                                                            => 'Limelight',
			'"Linden Hill", "regular:italic", serif'                                                                                                                                     => 'Linden Hill',
			'"Linefont", "100:200:300:regular:500:600:700:800:900", display'                                                                                                             => 'Linefont',
			'"Lisu Bosa", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", serif'                                     => 'Lisu Bosa',
			'"Literata", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                                      => 'Literata',
			'"Liu Jian Mao Cao", "regular", handwriting'                                                                                                                                 => 'Liu Jian Mao Cao',
			'"Livvic", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:900:900italic", sans-serif'                                   => 'Livvic',
			'"Lobster", "regular", display'                                                                                                                                              => 'Lobster',
			'"Lobster Two", "regular:italic:700:700italic", display'                                                                                                                     => 'Lobster Two',
			'"Londrina Outline", "regular", display'                                                                                                                                     => 'Londrina Outline',
			'"Londrina Shadow", "regular", display'                                                                                                                                      => 'Londrina Shadow',
			'"Londrina Sketch", "regular", display'                                                                                                                                      => 'Londrina Sketch',
			'"Londrina Solid", "100:300:regular:900", display'                                                                                                                           => 'Londrina Solid',
			'"Long Cang", "regular", handwriting'                                                                                                                                        => 'Long Cang',
			'"Lora", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                                  => 'Lora',
			'"Love Light", "regular", handwriting'                                                                                                                                       => 'Love Light',
			'"Love Ya Like A Sister", "regular", display'                                                                                                                                => 'Love Ya Like A Sister',
			'"Loved by the King", "regular", handwriting'                                                                                                                                => 'Loved by the King',
			'"Lovers Quarrel", "regular", handwriting'                                                                                                                                   => 'Lovers Quarrel',
			'"Luckiest Guy", "regular", display'                                                                                                                                         => 'Luckiest Guy',
			'"Lugrasimo", "regular", handwriting'                                                                                                                                        => 'Lugrasimo',
			'"Lumanosimo", "regular", handwriting'                                                                                                                                       => 'Lumanosimo',
			'"Lunasima", "regular:700", sans-serif'                                                                                                                                      => 'Lunasima',
			'"Lusitana", "regular:700", serif'                                                                                                                                           => 'Lusitana',
			'"Lustria", "regular", serif'                                                                                                                                                => 'Lustria',
			'"Luxurious Roman", "regular", display'                                                                                                                                      => 'Luxurious Roman',
			'"Luxurious Script", "regular", handwriting'                                                                                                                                 => 'Luxurious Script',
			'"M PLUS 1", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                          => 'M PLUS 1',
			'"M PLUS 1 Code", "100:200:300:regular:500:600:700", monospace'                                                                                                              => 'M PLUS 1 Code',
			'"M PLUS 1p", "100:300:regular:500:700:800:900", sans-serif'                                                                                                                 => 'M PLUS 1p',
			'"M PLUS 2", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                          => 'M PLUS 2',
			'"M PLUS Code Latin", "100:200:300:regular:500:600:700", sans-serif'                                                                                                         => 'M PLUS Code Latin',
			'"M PLUS Rounded 1c", "100:300:regular:500:700:800:900", sans-serif'                                                                                                         => 'M PLUS Rounded 1c',
			'"Ma Shan Zheng", "regular", handwriting'                                                                                                                                    => 'Ma Shan Zheng',
			'"Macondo", "regular", display'                                                                                                                                              => 'Macondo',
			'"Macondo Swash Caps", "regular", display'                                                                                                                                   => 'Macondo Swash Caps',
			'"Mada", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                                  => 'Mada',
			'"Madimi One", "regular", sans-serif'                                                                                                                                        => 'Madimi One',
			'"Magra", "regular:700", sans-serif'                                                                                                                                         => 'Magra',
			'"Maiden Orange", "regular", serif'                                                                                                                                          => 'Maiden Orange',
			'"Maitree", "200:300:regular:500:600:700", serif'                                                                                                                            => 'Maitree',
			'"Major Mono Display", "regular", monospace'                                                                                                                                 => 'Major Mono Display',
			'"Mako", "regular", sans-serif'                                                                                                                                              => 'Mako',
			'"Mali", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", handwriting'                                                                => 'Mali',
			'"Mallanna", "regular", sans-serif'                                                                                                                                          => 'Mallanna',
			'"Maname", "regular", serif'                                                                                                                                                 => 'Maname',
			'"Mandali", "regular", sans-serif'                                                                                                                                           => 'Mandali',
			'"Manjari", "100:regular:700", sans-serif'                                                                                                                                   => 'Manjari',
			'"Manrope", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                   => 'Manrope',
			'"Mansalva", "regular", handwriting'                                                                                                                                         => 'Mansalva',
			'"Manuale", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", serif'                                                                   => 'Manuale',
			'"Marcellus", "regular", serif'                                                                                                                                              => 'Marcellus',
			'"Marcellus SC", "regular", serif'                                                                                                                                           => 'Marcellus SC',
			'"Marck Script", "regular", handwriting'                                                                                                                                     => 'Marck Script',
			'"Margarine", "regular", display'                                                                                                                                            => 'Margarine',
			'"Marhey", "300:regular:500:600:700", display'                                                                                                                               => 'Marhey',
			'"Markazi Text", "regular:500:600:700", serif'                                                                                                                               => 'Markazi Text',
			'"Marko One", "regular", serif'                                                                                                                                              => 'Marko One',
			'"Marmelad", "regular", sans-serif'                                                                                                                                          => 'Marmelad',
			'"Martel", "200:300:regular:600:700:800:900", serif'                                                                                                                         => 'Martel',
			'"Martel Sans", "200:300:regular:600:700:800:900", sans-serif'                                                                                                               => 'Martel Sans',
			'"Martian Mono", "100:200:300:regular:500:600:700:800", monospace'                                                                                                           => 'Martian Mono',
			'"Marvel", "regular:italic:700:700italic", sans-serif'                                                                                                                       => 'Marvel',
			'"Mate", "regular:italic", serif'                                                                                                                                            => 'Mate',
			'"Mate SC", "regular", serif'                                                                                                                                                => 'Mate SC',
			'"Material Icons", "regular", monospace'                                                                                                                                     => 'Material Icons',
			'"Material Icons Outlined", "regular", monospace'                                                                                                                            => 'Material Icons Outlined',
			'"Material Icons Round", "regular", monospace'                                                                                                                               => 'Material Icons Round',
			'"Material Icons Sharp", "regular", monospace'                                                                                                                               => 'Material Icons Sharp',
			'"Material Icons Two Tone", "regular", monospace'                                                                                                                            => 'Material Icons Two Tone',
			'"Material Symbols Outlined", "100:200:300:regular:500:600:700", monospace'                                                                                                  => 'Material Symbols Outlined',
			'"Material Symbols Rounded", "100:200:300:regular:500:600:700", monospace'                                                                                                   => 'Material Symbols Rounded',
			'"Material Symbols Sharp", "100:200:300:regular:500:600:700", monospace'                                                                                                     => 'Material Symbols Sharp',
			'"Maven Pro", "regular:500:600:700:800:900", sans-serif'                                                                                                                     => 'Maven Pro',
			'"McLaren", "regular", display'                                                                                                                                              => 'McLaren',
			'"Mea Culpa", "regular", handwriting'                                                                                                                                        => 'Mea Culpa',
			'"Meddon", "regular", handwriting'                                                                                                                                           => 'Meddon',
			'"MedievalSharp", "regular", display'                                                                                                                                        => 'MedievalSharp',
			'"Medula One", "regular", display'                                                                                                                                           => 'Medula One',
			'"Meera Inimai", "regular", sans-serif'                                                                                                                                      => 'Meera Inimai',
			'"Megrim", "regular", display'                                                                                                                                               => 'Megrim',
			'"Meie Script", "regular", handwriting'                                                                                                                                      => 'Meie Script',
			'"Meow Script", "regular", handwriting'                                                                                                                                      => 'Meow Script',
			'"Merienda", "300:regular:500:600:700:800:900", handwriting'                                                                                                                 => 'Merienda',
			'"Merriweather", "300:300italic:regular:italic:700:700italic:900:900italic", serif'                                                                                          => 'Merriweather',
			'"Merriweather Sans", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                                                    => 'Merriweather Sans',
			'"Metal", "regular", display'                                                                                                                                                => 'Metal',
			'"Metal Mania", "regular", display'                                                                                                                                          => 'Metal Mania',
			'"Metamorphous", "regular", display'                                                                                                                                         => 'Metamorphous',
			'"Metrophobic", "regular", sans-serif'                                                                                                                                       => 'Metrophobic',
			'"Michroma", "regular", sans-serif'                                                                                                                                          => 'Michroma',
			'"Micro 5", "regular", display'                                                                                                                                              => 'Micro 5',
			'"Micro 5 Charted", "regular", display'                                                                                                                                      => 'Micro 5 Charted',
			'"Milonga", "regular", display'                                                                                                                                              => 'Milonga',
			'"Miltonian", "regular", display'                                                                                                                                            => 'Miltonian',
			'"Miltonian Tattoo", "regular", display'                                                                                                                                     => 'Miltonian Tattoo',
			'"Mina", "regular:700", sans-serif'                                                                                                                                          => 'Mina',
			'"Mingzat", "regular", sans-serif'                                                                                                                                           => 'Mingzat',
			'"Miniver", "regular", display'                                                                                                                                              => 'Miniver',
			'"Miriam Libre", "regular:700", sans-serif'                                                                                                                                  => 'Miriam Libre',
			'"Mirza", "regular:500:600:700", serif'                                                                                                                                      => 'Mirza',
			'"Miss Fajardose", "regular", handwriting'                                                                                                                                   => 'Miss Fajardose',
			'"Mitr", "200:300:regular:500:600:700", sans-serif'                                                                                                                          => 'Mitr',
			'"Mochiy Pop One", "regular", sans-serif'                                                                                                                                    => 'Mochiy Pop One',
			'"Mochiy Pop P One", "regular", sans-serif'                                                                                                                                  => 'Mochiy Pop P One',
			'"Modak", "regular", display'                                                                                                                                                => 'Modak',
			'"Modern Antiqua", "regular", display'                                                                                                                                       => 'Modern Antiqua',
			'"Mogra", "regular", display'                                                                                                                                                => 'Mogra',
			'"Mohave", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", sans-serif'                                                                             => 'Mohave',
			'"Moirai One", "regular", display'                                                                                                                                           => 'Moirai One',
			'"Molengo", "regular", sans-serif'                                                                                                                                           => 'Molengo',
			'"Molle", "italic", handwriting'                                                                                                                                             => 'Molle',
			'"Monda", "regular:500:600:700", sans-serif'                                                                                                                                 => 'Monda',
			'"Monofett", "regular", monospace'                                                                                                                                           => 'Monofett',
			'"Monomaniac One", "regular", sans-serif'                                                                                                                                    => 'Monomaniac One',
			'"Monoton", "regular", display'                                                                                                                                              => 'Monoton',
			'"Monsieur La Doulaise", "regular", handwriting'                                                                                                                             => 'Monsieur La Doulaise',
			'"Montaga", "regular", serif'                                                                                                                                                => 'Montaga',
			'"Montagu Slab", "100:200:300:regular:500:600:700", serif'                                                                                                                   => 'Montagu Slab',
			'"MonteCarlo", "regular", handwriting'                                                                                                                                       => 'MonteCarlo',
			'"Montez", "regular", handwriting'                                                                                                                                           => 'Montez',
			'"Montserrat", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                 => 'Montserrat',
			'"Montserrat Alternates", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'      => 'Montserrat Alternates',
			'"Montserrat Subrayada", "regular:700", sans-serif'                                                                                                                          => 'Montserrat Subrayada',
			'"Moo Lah Lah", "regular", display'                                                                                                                                          => 'Moo Lah Lah',
			'"Mooli", "regular", sans-serif'                                                                                                                                             => 'Mooli',
			'"Moon Dance", "regular", handwriting'                                                                                                                                       => 'Moon Dance',
			'"Moul", "regular", display'                                                                                                                                                 => 'Moul',
			'"Moulpali", "regular", sans-serif'                                                                                                                                          => 'Moulpali',
			'"Mountains of Christmas", "regular:700", display'                                                                                                                           => 'Mountains of Christmas',
			'"Mouse Memoirs", "regular", sans-serif'                                                                                                                                     => 'Mouse Memoirs',
			'"Mr Bedfort", "regular", handwriting'                                                                                                                                       => 'Mr Bedfort',
			'"Mr Dafoe", "regular", handwriting'                                                                                                                                         => 'Mr Dafoe',
			'"Mr De Haviland", "regular", handwriting'                                                                                                                                   => 'Mr De Haviland',
			'"Mrs Saint Delafield", "regular", handwriting'                                                                                                                              => 'Mrs Saint Delafield',
			'"Mrs Sheppards", "regular", handwriting'                                                                                                                                    => 'Mrs Sheppards',
			'"Ms Madi", "regular", handwriting'                                                                                                                                          => 'Ms Madi',
			'"Mukta", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                     => 'Mukta',
			'"Mukta Mahee", "200:300:regular:500:600:700:800", sans-serif'                                                                                                               => 'Mukta Mahee',
			'"Mukta Malar", "200:300:regular:500:600:700:800", sans-serif'                                                                                                               => 'Mukta Malar',
			'"Mukta Vaani", "200:300:regular:500:600:700:800", sans-serif'                                                                                                               => 'Mukta Vaani',
			'"Mulish", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                   => 'Mulish',
			'"Murecho", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                           => 'Murecho',
			'"MuseoModerno", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", display'                  => 'MuseoModerno',
			'"My Soul", "regular", handwriting'                                                                                                                                          => 'My Soul',
			'"Mynerve", "regular", handwriting'                                                                                                                                          => 'Mynerve',
			'"Mystery Quest", "regular", display'                                                                                                                                        => 'Mystery Quest',
			'"NTR", "regular", sans-serif'                                                                                                                                               => 'NTR',
			'"Nabla", "regular", display'                                                                                                                                                => 'Nabla',
			'"Namdhinggo", "regular:500:600:700:800", serif'                                                                                                                             => 'Namdhinggo',
			'"Nanum Brush Script", "regular", handwriting'                                                                                                                               => 'Nanum Brush Script',
			'"Nanum Gothic", "regular:700:800", sans-serif'                                                                                                                              => 'Nanum Gothic',
			'"Nanum Gothic Coding", "regular:700", handwriting'                                                                                                                          => 'Nanum Gothic Coding',
			'"Nanum Myeongjo", "regular:700:800", serif'                                                                                                                                 => 'Nanum Myeongjo',
			'"Nanum Pen Script", "regular", handwriting'                                                                                                                                 => 'Nanum Pen Script',
			'"Narnoor", "regular:500:600:700:800", serif'                                                                                                                                => 'Narnoor',
			'"Neonderthaw", "regular", handwriting'                                                                                                                                      => 'Neonderthaw',
			'"Nerko One", "regular", handwriting'                                                                                                                                        => 'Nerko One',
			'"Neucha", "regular", handwriting'                                                                                                                                           => 'Neucha',
			'"Neuton", "200:300:regular:italic:700:800", serif'                                                                                                                          => 'Neuton',
			'"New Rocker", "regular", display'                                                                                                                                           => 'New Rocker',
			'"New Tegomin", "regular", serif'                                                                                                                                            => 'New Tegomin',
			'"News Cycle", "regular:700", sans-serif'                                                                                                                                    => 'News Cycle',
			'"Newsreader", "200:300:regular:500:600:700:800:200italic:300italic:italic:500italic:600italic:700italic:800italic", serif'                                                  => 'Newsreader',
			'"Niconne", "regular", handwriting'                                                                                                                                          => 'Niconne',
			'"Niramit", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", sans-serif'                                                              => 'Niramit',
			'"Nixie One", "regular", display'                                                                                                                                            => 'Nixie One',
			'"Nobile", "regular:italic:500:500italic:700:700italic", sans-serif'                                                                                                         => 'Nobile',
			'"Nokora", "100:300:regular:700:900", sans-serif'                                                                                                                            => 'Nokora',
			'"Norican", "regular", handwriting'                                                                                                                                          => 'Norican',
			'"Nosifer", "regular", display'                                                                                                                                              => 'Nosifer',
			'"Notable", "regular", sans-serif'                                                                                                                                           => 'Notable',
			'"Nothing You Could Do", "regular", handwriting'                                                                                                                             => 'Nothing You Could Do',
			'"Noticia Text", "regular:italic:700:700italic", serif'                                                                                                                      => 'Noticia Text',
			'"Noto Color Emoji", "regular", sans-serif'                                                                                                                                  => 'Noto Color Emoji',
			'"Noto Emoji", "300:regular:500:600:700", sans-serif'                                                                                                                        => 'Noto Emoji',
			'"Noto Kufi Arabic", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Kufi Arabic',
			'"Noto Music", "regular", sans-serif'                                                                                                                                        => 'Noto Music',
			'"Noto Naskh Arabic", "regular:500:600:700", serif'                                                                                                                          => 'Noto Naskh Arabic',
			'"Noto Nastaliq Urdu", "regular:500:600:700", serif'                                                                                                                         => 'Noto Nastaliq Urdu',
			'"Noto Rashi Hebrew", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                      => 'Noto Rashi Hebrew',
			'"Noto Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                  => 'Noto Sans',
			'"Noto Sans Adlam", "regular:500:600:700", sans-serif'                                                                                                                       => 'Noto Sans Adlam',
			'"Noto Sans Adlam Unjoined", "regular:500:600:700", sans-serif'                                                                                                              => 'Noto Sans Adlam Unjoined',
			'"Noto Sans Anatolian Hieroglyphs", "regular", sans-serif'                                                                                                                   => 'Noto Sans Anatolian Hieroglyphs',
			'"Noto Sans Arabic", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Sans Arabic',
			'"Noto Sans Armenian", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Armenian',
			'"Noto Sans Avestan", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Avestan',
			'"Noto Sans Balinese", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Balinese',
			'"Noto Sans Bamum", "regular:500:600:700", sans-serif'                                                                                                                       => 'Noto Sans Bamum',
			'"Noto Sans Bassa Vah", "regular:500:600:700", sans-serif'                                                                                                                   => 'Noto Sans Bassa Vah',
			'"Noto Sans Batak", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Batak',
			'"Noto Sans Bengali", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Noto Sans Bengali',
			'"Noto Sans Bhaiksuki", "regular", sans-serif'                                                                                                                               => 'Noto Sans Bhaiksuki',
			'"Noto Sans Brahmi", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Brahmi',
			'"Noto Sans Buginese", "regular", sans-serif'                                                                                                                                => 'Noto Sans Buginese',
			'"Noto Sans Buhid", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Buhid',
			'"Noto Sans Canadian Aboriginal", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                     => 'Noto Sans Canadian Aboriginal',
			'"Noto Sans Carian", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Carian',
			'"Noto Sans Caucasian Albanian", "regular", sans-serif'                                                                                                                      => 'Noto Sans Caucasian Albanian',
			'"Noto Sans Chakma", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Chakma',
			'"Noto Sans Cham", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                    => 'Noto Sans Cham',
			'"Noto Sans Cherokee", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Cherokee',
			'"Noto Sans Chorasmian", "regular", sans-serif'                                                                                                                              => 'Noto Sans Chorasmian',
			'"Noto Sans Coptic", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Coptic',
			'"Noto Sans Cuneiform", "regular", sans-serif'                                                                                                                               => 'Noto Sans Cuneiform',
			'"Noto Sans Cypriot", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Cypriot',
			'"Noto Sans Cypro Minoan", "regular", sans-serif'                                                                                                                            => 'Noto Sans Cypro Minoan',
			'"Noto Sans Deseret", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Deseret',
			'"Noto Sans Devanagari", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                              => 'Noto Sans Devanagari',
			'"Noto Sans Display", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'          => 'Noto Sans Display',
			'"Noto Sans Duployan", "regular:700", sans-serif'                                                                                                                            => 'Noto Sans Duployan',
			'"Noto Sans Egyptian Hieroglyphs", "regular", sans-serif'                                                                                                                    => 'Noto Sans Egyptian Hieroglyphs',
			'"Noto Sans Elbasan", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Elbasan',
			'"Noto Sans Elymaic", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Elymaic',
			'"Noto Sans Ethiopic", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Ethiopic',
			'"Noto Sans Georgian", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Georgian',
			'"Noto Sans Glagolitic", "regular", sans-serif'                                                                                                                              => 'Noto Sans Glagolitic',
			'"Noto Sans Gothic", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Gothic',
			'"Noto Sans Grantha", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Grantha',
			'"Noto Sans Gujarati", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Gujarati',
			'"Noto Sans Gunjala Gondi", "regular:500:600:700", sans-serif'                                                                                                               => 'Noto Sans Gunjala Gondi',
			'"Noto Sans Gurmukhi", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                => 'Noto Sans Gurmukhi',
			'"Noto Sans HK", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Noto Sans HK',
			'"Noto Sans Hanifi Rohingya", "regular:500:600:700", sans-serif'                                                                                                             => 'Noto Sans Hanifi Rohingya',
			'"Noto Sans Hanunoo", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Hanunoo',
			'"Noto Sans Hatran", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Hatran',
			'"Noto Sans Hebrew", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Sans Hebrew',
			'"Noto Sans Imperial Aramaic", "regular", sans-serif'                                                                                                                        => 'Noto Sans Imperial Aramaic',
			'"Noto Sans Indic Siyaq Numbers", "regular", sans-serif'                                                                                                                     => 'Noto Sans Indic Siyaq Numbers',
			'"Noto Sans Inscriptional Pahlavi", "regular", sans-serif'                                                                                                                   => 'Noto Sans Inscriptional Pahlavi',
			'"Noto Sans Inscriptional Parthian", "regular", sans-serif'                                                                                                                  => 'Noto Sans Inscriptional Parthian',
			'"Noto Sans JP", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Noto Sans JP',
			'"Noto Sans Javanese", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Javanese',
			'"Noto Sans KR", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Noto Sans KR',
			'"Noto Sans Kaithi", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Kaithi',
			'"Noto Sans Kannada", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Noto Sans Kannada',
			'"Noto Sans Kawi", "regular:500:600:700", sans-serif'                                                                                                                        => 'Noto Sans Kawi',
			'"Noto Sans Kayah Li", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Kayah Li',
			'"Noto Sans Kharoshthi", "regular", sans-serif'                                                                                                                              => 'Noto Sans Kharoshthi',
			'"Noto Sans Khmer", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                   => 'Noto Sans Khmer',
			'"Noto Sans Khojki", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Khojki',
			'"Noto Sans Khudawadi", "regular", sans-serif'                                                                                                                               => 'Noto Sans Khudawadi',
			'"Noto Sans Lao", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                     => 'Noto Sans Lao',
			'"Noto Sans Lao Looped", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                              => 'Noto Sans Lao Looped',
			'"Noto Sans Lepcha", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Lepcha',
			'"Noto Sans Limbu", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Limbu',
			'"Noto Sans Linear A", "regular", sans-serif'                                                                                                                                => 'Noto Sans Linear A',
			'"Noto Sans Linear B", "regular", sans-serif'                                                                                                                                => 'Noto Sans Linear B',
			'"Noto Sans Lisu", "regular:500:600:700", sans-serif'                                                                                                                        => 'Noto Sans Lisu',
			'"Noto Sans Lycian", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Lycian',
			'"Noto Sans Lydian", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Lydian',
			'"Noto Sans Mahajani", "regular", sans-serif'                                                                                                                                => 'Noto Sans Mahajani',
			'"Noto Sans Malayalam", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                               => 'Noto Sans Malayalam',
			'"Noto Sans Mandaic", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Mandaic',
			'"Noto Sans Manichaean", "regular", sans-serif'                                                                                                                              => 'Noto Sans Manichaean',
			'"Noto Sans Marchen", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Marchen',
			'"Noto Sans Masaram Gondi", "regular", sans-serif'                                                                                                                           => 'Noto Sans Masaram Gondi',
			'"Noto Sans Math", "regular", sans-serif'                                                                                                                                    => 'Noto Sans Math',
			'"Noto Sans Mayan Numerals", "regular", sans-serif'                                                                                                                          => 'Noto Sans Mayan Numerals',
			'"Noto Sans Medefaidrin", "regular:500:600:700", sans-serif'                                                                                                                 => 'Noto Sans Medefaidrin',
			'"Noto Sans Meetei Mayek", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                            => 'Noto Sans Meetei Mayek',
			'"Noto Sans Mende Kikakui", "regular", sans-serif'                                                                                                                           => 'Noto Sans Mende Kikakui',
			'"Noto Sans Meroitic", "regular", sans-serif'                                                                                                                                => 'Noto Sans Meroitic',
			'"Noto Sans Miao", "regular", sans-serif'                                                                                                                                    => 'Noto Sans Miao',
			'"Noto Sans Modi", "regular", sans-serif'                                                                                                                                    => 'Noto Sans Modi',
			'"Noto Sans Mongolian", "regular", sans-serif'                                                                                                                               => 'Noto Sans Mongolian',
			'"Noto Sans Mono", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                    => 'Noto Sans Mono',
			'"Noto Sans Mro", "regular", sans-serif'                                                                                                                                     => 'Noto Sans Mro',
			'"Noto Sans Multani", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Multani',
			'"Noto Sans Myanmar", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Noto Sans Myanmar',
			'"Noto Sans NKo", "regular", sans-serif'                                                                                                                                     => 'Noto Sans NKo',
			'"Noto Sans NKo Unjoined", "regular:500:600:700", sans-serif'                                                                                                                => 'Noto Sans NKo Unjoined',
			'"Noto Sans Nabataean", "regular", sans-serif'                                                                                                                               => 'Noto Sans Nabataean',
			'"Noto Sans Nag Mundari", "regular:500:600:700", sans-serif'                                                                                                                 => 'Noto Sans Nag Mundari',
			'"Noto Sans Nandinagari", "regular", sans-serif'                                                                                                                             => 'Noto Sans Nandinagari',
			'"Noto Sans New Tai Lue", "regular:500:600:700", sans-serif'                                                                                                                 => 'Noto Sans New Tai Lue',
			'"Noto Sans Newa", "regular", sans-serif'                                                                                                                                    => 'Noto Sans Newa',
			'"Noto Sans Nushu", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Nushu',
			'"Noto Sans Ogham", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Ogham',
			'"Noto Sans Ol Chiki", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Ol Chiki',
			'"Noto Sans Old Hungarian", "regular", sans-serif'                                                                                                                           => 'Noto Sans Old Hungarian',
			'"Noto Sans Old Italic", "regular", sans-serif'                                                                                                                              => 'Noto Sans Old Italic',
			'"Noto Sans Old North Arabian", "regular", sans-serif'                                                                                                                       => 'Noto Sans Old North Arabian',
			'"Noto Sans Old Permic", "regular", sans-serif'                                                                                                                              => 'Noto Sans Old Permic',
			'"Noto Sans Old Persian", "regular", sans-serif'                                                                                                                             => 'Noto Sans Old Persian',
			'"Noto Sans Old Sogdian", "regular", sans-serif'                                                                                                                             => 'Noto Sans Old Sogdian',
			'"Noto Sans Old South Arabian", "regular", sans-serif'                                                                                                                       => 'Noto Sans Old South Arabian',
			'"Noto Sans Old Turkic", "regular", sans-serif'                                                                                                                              => 'Noto Sans Old Turkic',
			'"Noto Sans Oriya", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                   => 'Noto Sans Oriya',
			'"Noto Sans Osage", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Osage',
			'"Noto Sans Osmanya", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Osmanya',
			'"Noto Sans Pahawh Hmong", "regular", sans-serif'                                                                                                                            => 'Noto Sans Pahawh Hmong',
			'"Noto Sans Palmyrene", "regular", sans-serif'                                                                                                                               => 'Noto Sans Palmyrene',
			'"Noto Sans Pau Cin Hau", "regular", sans-serif'                                                                                                                             => 'Noto Sans Pau Cin Hau',
			'"Noto Sans Phags Pa", "regular", sans-serif'                                                                                                                                => 'Noto Sans Phags Pa',
			'"Noto Sans Phoenician", "regular", sans-serif'                                                                                                                              => 'Noto Sans Phoenician',
			'"Noto Sans Psalter Pahlavi", "regular", sans-serif'                                                                                                                         => 'Noto Sans Psalter Pahlavi',
			'"Noto Sans Rejang", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Rejang',
			'"Noto Sans Runic", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Runic',
			'"Noto Sans SC", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Noto Sans SC',
			'"Noto Sans Samaritan", "regular", sans-serif'                                                                                                                               => 'Noto Sans Samaritan',
			'"Noto Sans Saurashtra", "regular", sans-serif'                                                                                                                              => 'Noto Sans Saurashtra',
			'"Noto Sans Sharada", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Sharada',
			'"Noto Sans Shavian", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Shavian',
			'"Noto Sans Siddham", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Siddham',
			'"Noto Sans SignWriting", "regular", sans-serif'                                                                                                                             => 'Noto Sans SignWriting',
			'"Noto Sans Sinhala", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Noto Sans Sinhala',
			'"Noto Sans Sogdian", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Sogdian',
			'"Noto Sans Sora Sompeng", "regular:500:600:700", sans-serif'                                                                                                                => 'Noto Sans Sora Sompeng',
			'"Noto Sans Soyombo", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Soyombo',
			'"Noto Sans Sundanese", "regular:500:600:700", sans-serif'                                                                                                                   => 'Noto Sans Sundanese',
			'"Noto Sans Syloti Nagri", "regular", sans-serif'                                                                                                                            => 'Noto Sans Syloti Nagri',
			'"Noto Sans Symbols", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Noto Sans Symbols',
			'"Noto Sans Symbols 2", "regular", sans-serif'                                                                                                                               => 'Noto Sans Symbols 2',
			'"Noto Sans Syriac", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Sans Syriac',
			'"Noto Sans Syriac Eastern", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                          => 'Noto Sans Syriac Eastern',
			'"Noto Sans TC", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                      => 'Noto Sans TC',
			'"Noto Sans Tagalog", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Tagalog',
			'"Noto Sans Tagbanwa", "regular", sans-serif'                                                                                                                                => 'Noto Sans Tagbanwa',
			'"Noto Sans Tai Le", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Tai Le',
			'"Noto Sans Tai Tham", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Tai Tham',
			'"Noto Sans Tai Viet", "regular", sans-serif'                                                                                                                                => 'Noto Sans Tai Viet',
			'"Noto Sans Takri", "regular", sans-serif'                                                                                                                                   => 'Noto Sans Takri',
			'"Noto Sans Tamil", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                   => 'Noto Sans Tamil',
			'"Noto Sans Tamil Supplement", "regular", sans-serif'                                                                                                                        => 'Noto Sans Tamil Supplement',
			'"Noto Sans Tangsa", "regular:500:600:700", sans-serif'                                                                                                                      => 'Noto Sans Tangsa',
			'"Noto Sans Telugu", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Sans Telugu',
			'"Noto Sans Thaana", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                  => 'Noto Sans Thaana',
			'"Noto Sans Thai", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                    => 'Noto Sans Thai',
			'"Noto Sans Thai Looped", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                             => 'Noto Sans Thai Looped',
			'"Noto Sans Tifinagh", "regular", sans-serif'                                                                                                                                => 'Noto Sans Tifinagh',
			'"Noto Sans Tirhuta", "regular", sans-serif'                                                                                                                                 => 'Noto Sans Tirhuta',
			'"Noto Sans Ugaritic", "regular", sans-serif'                                                                                                                                => 'Noto Sans Ugaritic',
			'"Noto Sans Vai", "regular", sans-serif'                                                                                                                                     => 'Noto Sans Vai',
			'"Noto Sans Vithkuqi", "regular:500:600:700", sans-serif'                                                                                                                    => 'Noto Sans Vithkuqi',
			'"Noto Sans Wancho", "regular", sans-serif'                                                                                                                                  => 'Noto Sans Wancho',
			'"Noto Sans Warang Citi", "regular", sans-serif'                                                                                                                             => 'Noto Sans Warang Citi',
			'"Noto Sans Yi", "regular", sans-serif'                                                                                                                                      => 'Noto Sans Yi',
			'"Noto Sans Zanabazar Square", "regular", sans-serif'                                                                                                                        => 'Noto Sans Zanabazar Square',
			'"Noto Serif", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                      => 'Noto Serif',
			'"Noto Serif Ahom", "regular", serif'                                                                                                                                        => 'Noto Serif Ahom',
			'"Noto Serif Armenian", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                    => 'Noto Serif Armenian',
			'"Noto Serif Balinese", "regular", serif'                                                                                                                                    => 'Noto Serif Balinese',
			'"Noto Serif Bengali", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                     => 'Noto Serif Bengali',
			'"Noto Serif Devanagari", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                  => 'Noto Serif Devanagari',
			'"Noto Serif Display", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'              => 'Noto Serif Display',
			'"Noto Serif Dogra", "regular", serif'                                                                                                                                       => 'Noto Serif Dogra',
			'"Noto Serif Ethiopic", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                    => 'Noto Serif Ethiopic',
			'"Noto Serif Georgian", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                    => 'Noto Serif Georgian',
			'"Noto Serif Grantha", "regular", serif'                                                                                                                                     => 'Noto Serif Grantha',
			'"Noto Serif Gujarati", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                    => 'Noto Serif Gujarati',
			'"Noto Serif Gurmukhi", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                    => 'Noto Serif Gurmukhi',
			'"Noto Serif HK", "200:300:regular:500:600:700:800:900", serif'                                                                                                              => 'Noto Serif HK',
			'"Noto Serif Hebrew", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                      => 'Noto Serif Hebrew',
			'"Noto Serif JP", "200:300:regular:500:600:700:800:900", serif'                                                                                                              => 'Noto Serif JP',
			'"Noto Serif KR", "200:300:regular:500:600:700:800:900", serif'                                                                                                              => 'Noto Serif KR',
			'"Noto Serif Kannada", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                     => 'Noto Serif Kannada',
			'"Noto Serif Khitan Small Script", "regular", serif'                                                                                                                         => 'Noto Serif Khitan Small Script',
			'"Noto Serif Khmer", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                       => 'Noto Serif Khmer',
			'"Noto Serif Khojki", "regular:500:600:700", serif'                                                                                                                          => 'Noto Serif Khojki',
			'"Noto Serif Lao", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                         => 'Noto Serif Lao',
			'"Noto Serif Makasar", "regular", serif'                                                                                                                                     => 'Noto Serif Makasar',
			'"Noto Serif Malayalam", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                   => 'Noto Serif Malayalam',
			'"Noto Serif Myanmar", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                     => 'Noto Serif Myanmar',
			'"Noto Serif NP Hmong", "regular:500:600:700", serif'                                                                                                                        => 'Noto Serif NP Hmong',
			'"Noto Serif Old Uyghur", "regular", serif'                                                                                                                                  => 'Noto Serif Old Uyghur',
			'"Noto Serif Oriya", "regular:500:600:700", serif'                                                                                                                           => 'Noto Serif Oriya',
			'"Noto Serif Ottoman Siyaq", "regular", serif'                                                                                                                               => 'Noto Serif Ottoman Siyaq',
			'"Noto Serif SC", "200:300:regular:500:600:700:800:900", serif'                                                                                                              => 'Noto Serif SC',
			'"Noto Serif Sinhala", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                     => 'Noto Serif Sinhala',
			'"Noto Serif TC", "200:300:regular:500:600:700:800:900", serif'                                                                                                              => 'Noto Serif TC',
			'"Noto Serif Tamil", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                => 'Noto Serif Tamil',
			'"Noto Serif Tangut", "regular", serif'                                                                                                                                      => 'Noto Serif Tangut',
			'"Noto Serif Telugu", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                      => 'Noto Serif Telugu',
			'"Noto Serif Thai", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                        => 'Noto Serif Thai',
			'"Noto Serif Tibetan", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                     => 'Noto Serif Tibetan',
			'"Noto Serif Toto", "regular:500:600:700", serif'                                                                                                                            => 'Noto Serif Toto',
			'"Noto Serif Vithkuqi", "regular:500:600:700", serif'                                                                                                                        => 'Noto Serif Vithkuqi',
			'"Noto Serif Yezidi", "regular:500:600:700", serif'                                                                                                                          => 'Noto Serif Yezidi',
			'"Noto Traditional Nushu", "300:regular:500:600:700", sans-serif'                                                                                                            => 'Noto Traditional Nushu',
			'"Noto Znamenny Musical Notation", "regular", sans-serif'                                                                                                                    => 'Noto Znamenny Musical Notation',
			'"Nova Cut", "regular", display'                                                                                                                                             => 'Nova Cut',
			'"Nova Flat", "regular", display'                                                                                                                                            => 'Nova Flat',
			'"Nova Mono", "regular", monospace'                                                                                                                                          => 'Nova Mono',
			'"Nova Oval", "regular", display'                                                                                                                                            => 'Nova Oval',
			'"Nova Round", "regular", display'                                                                                                                                           => 'Nova Round',
			'"Nova Script", "regular", display'                                                                                                                                          => 'Nova Script',
			'"Nova Slim", "regular", display'                                                                                                                                            => 'Nova Slim',
			'"Nova Square", "regular", display'                                                                                                                                          => 'Nova Square',
			'"Numans", "regular", sans-serif'                                                                                                                                            => 'Numans',
			'"Nunito", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                   => 'Nunito',
			'"Nunito Sans", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                              => 'Nunito Sans',
			'"Nuosu SIL", "regular", sans-serif'                                                                                                                                         => 'Nuosu SIL',
			'"Odibee Sans", "regular", display'                                                                                                                                          => 'Odibee Sans',
			'"Odor Mean Chey", "regular", serif'                                                                                                                                         => 'Odor Mean Chey',
			'"Offside", "regular", display'                                                                                                                                              => 'Offside',
			'"Oi", "regular", display'                                                                                                                                                   => 'Oi',
			'"Ojuju", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                     => 'Ojuju',
			'"Old Standard TT", "regular:italic:700", serif'                                                                                                                             => 'Old Standard TT',
			'"Oldenburg", "regular", display'                                                                                                                                            => 'Oldenburg',
			'"Ole", "regular", handwriting'                                                                                                                                              => 'Ole',
			'"Oleo Script", "regular:700", display'                                                                                                                                      => 'Oleo Script',
			'"Oleo Script Swash Caps", "regular:700", display'                                                                                                                           => 'Oleo Script Swash Caps',
			'"Onest", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                             => 'Onest',
			'"Oooh Baby", "regular", handwriting'                                                                                                                                        => 'Oooh Baby',
			'"Open Sans", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                                                            => 'Open Sans',
			'"Oranienbaum", "regular", serif'                                                                                                                                            => 'Oranienbaum',
			'"Orbit", "regular", sans-serif'                                                                                                                                             => 'Orbit',
			'"Orbitron", "regular:500:600:700:800:900", sans-serif'                                                                                                                      => 'Orbitron',
			'"Oregano", "regular:italic", display'                                                                                                                                       => 'Oregano',
			'"Orelega One", "regular", display'                                                                                                                                          => 'Orelega One',
			'"Orienta", "regular", sans-serif'                                                                                                                                           => 'Orienta',
			'"Original Surfer", "regular", display'                                                                                                                                      => 'Original Surfer',
			'"Oswald", "200:300:regular:500:600:700", sans-serif'                                                                                                                        => 'Oswald',
			'"Outfit", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                            => 'Outfit',
			'"Over the Rainbow", "regular", handwriting'                                                                                                                                 => 'Over the Rainbow',
			'"Overlock", "regular:italic:700:700italic:900:900italic", display'                                                                                                          => 'Overlock',
			'"Overlock SC", "regular", display'                                                                                                                                          => 'Overlock SC',
			'"Overpass", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                   => 'Overpass',
			'"Overpass Mono", "300:regular:500:600:700", monospace'                                                                                                                      => 'Overpass Mono',
			'"Ovo", "regular", serif'                                                                                                                                                    => 'Ovo',
			'"Oxanium", "200:300:regular:500:600:700:800", display'                                                                                                                      => 'Oxanium',
			'"Oxygen", "300:regular:700", sans-serif'                                                                                                                                    => 'Oxygen',
			'"Oxygen Mono", "regular", monospace'                                                                                                                                        => 'Oxygen Mono',
			'"PT Mono", "regular", monospace'                                                                                                                                            => 'PT Mono',
			'"PT Sans", "regular:italic:700:700italic", sans-serif'                                                                                                                      => 'PT Sans',
			'"PT Sans Caption", "regular:700", sans-serif'                                                                                                                               => 'PT Sans Caption',
			'"PT Sans Narrow", "regular:700", sans-serif'                                                                                                                                => 'PT Sans Narrow',
			'"PT Serif", "regular:italic:700:700italic", serif'                                                                                                                          => 'PT Serif',
			'"PT Serif Caption", "regular:italic", serif'                                                                                                                                => 'PT Serif Caption',
			'"Pacifico", "regular", handwriting'                                                                                                                                         => 'Pacifico',
			'"Padauk", "regular:700", sans-serif'                                                                                                                                        => 'Padauk',
			'"Padyakke Expanded One", "regular", serif'                                                                                                                                  => 'Padyakke Expanded One',
			'"Palanquin", "100:200:300:regular:500:600:700", sans-serif'                                                                                                                 => 'Palanquin',
			'"Palanquin Dark", "regular:500:600:700", sans-serif'                                                                                                                        => 'Palanquin Dark',
			'"Palette Mosaic", "regular", display'                                                                                                                                       => 'Palette Mosaic',
			'"Pangolin", "regular", handwriting'                                                                                                                                         => 'Pangolin',
			'"Paprika", "regular", display'                                                                                                                                              => 'Paprika',
			'"Parisienne", "regular", handwriting'                                                                                                                                       => 'Parisienne',
			'"Passero One", "regular", display'                                                                                                                                          => 'Passero One',
			'"Passion One", "regular:700:900", display'                                                                                                                                  => 'Passion One',
			'"Passions Conflict", "regular", handwriting'                                                                                                                                => 'Passions Conflict',
			'"Pathway Extreme", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'            => 'Pathway Extreme',
			'"Pathway Gothic One", "regular", sans-serif'                                                                                                                                => 'Pathway Gothic One',
			'"Patrick Hand", "regular", handwriting'                                                                                                                                     => 'Patrick Hand',
			'"Patrick Hand SC", "regular", handwriting'                                                                                                                                  => 'Patrick Hand SC',
			'"Pattaya", "regular", sans-serif'                                                                                                                                           => 'Pattaya',
			'"Patua One", "regular", display'                                                                                                                                            => 'Patua One',
			'"Pavanam", "regular", sans-serif'                                                                                                                                           => 'Pavanam',
			'"Paytone One", "regular", sans-serif'                                                                                                                                       => 'Paytone One',
			'"Peddana", "regular", serif'                                                                                                                                                => 'Peddana',
			'"Peralta", "regular", serif'                                                                                                                                                => 'Peralta',
			'"Permanent Marker", "regular", handwriting'                                                                                                                                 => 'Permanent Marker',
			'"Petemoss", "regular", handwriting'                                                                                                                                         => 'Petemoss',
			'"Petit Formal Script", "regular", handwriting'                                                                                                                              => 'Petit Formal Script',
			'"Petrona", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                         => 'Petrona',
			'"Philosopher", "regular:italic:700:700italic", sans-serif'                                                                                                                  => 'Philosopher',
			'"Phudu", "300:regular:500:600:700:800:900", display'                                                                                                                        => 'Phudu',
			'"Piazzolla", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                       => 'Piazzolla',
			'"Piedra", "regular", display'                                                                                                                                               => 'Piedra',
			'"Pinyon Script", "regular", handwriting'                                                                                                                                    => 'Pinyon Script',
			'"Pirata One", "regular", display'                                                                                                                                           => 'Pirata One',
			'"Pixelify Sans", "regular:500:600:700", display'                                                                                                                            => 'Pixelify Sans',
			'"Plaster", "regular", display'                                                                                                                                              => 'Plaster',
			'"Platypi", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", serif'                                                                   => 'Platypi',
			'"Play", "regular:700", sans-serif'                                                                                                                                          => 'Play',
			'"Playball", "regular", display'                                                                                                                                             => 'Playball',
			'"Playfair", "300:regular:500:600:700:800:900:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                    => 'Playfair',
			'"Playfair Display", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                          => 'Playfair Display',
			'"Playfair Display SC", "regular:italic:700:700italic:900:900italic", serif'                                                                                                 => 'Playfair Display SC',
			'"Playpen Sans", "100:200:300:regular:500:600:700:800", handwriting'                                                                                                         => 'Playpen Sans',
			'"Playwrite AR", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite AR',
			'"Playwrite AT", "100:200:300:regular:100italic:200italic:300italic:italic", handwriting'                                                                                    => 'Playwrite AT',
			'"Playwrite AU NSW", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite AU NSW',
			'"Playwrite AU QLD", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite AU QLD',
			'"Playwrite AU SA", "100:200:300:regular", handwriting'                                                                                                                      => 'Playwrite AU SA',
			'"Playwrite AU TAS", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite AU TAS',
			'"Playwrite AU VIC", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite AU VIC',
			'"Playwrite BE VLG", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite BE VLG',
			'"Playwrite BE WAL", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite BE WAL',
			'"Playwrite BR", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite BR',
			'"Playwrite CA", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite CA',
			'"Playwrite CL", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite CL',
			'"Playwrite CO", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite CO',
			'"Playwrite CU", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite CU',
			'"Playwrite CZ", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite CZ',
			'"Playwrite DE Grund", "100:200:300:regular", handwriting'                                                                                                                   => 'Playwrite DE Grund',
			'"Playwrite DE LA", "100:200:300:regular", handwriting'                                                                                                                      => 'Playwrite DE LA',
			'"Playwrite DE SAS", "100:200:300:regular", handwriting'                                                                                                                     => 'Playwrite DE SAS',
			'"Playwrite DE VA", "100:200:300:regular", handwriting'                                                                                                                      => 'Playwrite DE VA',
			'"Playwrite DK Loopet", "100:200:300:regular", handwriting'                                                                                                                  => 'Playwrite DK Loopet',
			'"Playwrite DK Uloopet", "100:200:300:regular", handwriting'                                                                                                                 => 'Playwrite DK Uloopet',
			'"Playwrite ES", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite ES',
			'"Playwrite ES Deco", "100:200:300:regular", handwriting'                                                                                                                    => 'Playwrite ES Deco',
			'"Playwrite FR Moderne", "100:200:300:regular", handwriting'                                                                                                                 => 'Playwrite FR Moderne',
			'"Playwrite FR Trad", "100:200:300:regular", handwriting'                                                                                                                    => 'Playwrite FR Trad',
			'"Playwrite GB J", "100:200:300:regular:100italic:200italic:300italic:italic", handwriting'                                                                                  => 'Playwrite GB J',
			'"Playwrite GB S", "100:200:300:regular:100italic:200italic:300italic:italic", handwriting'                                                                                  => 'Playwrite GB S',
			'"Playwrite HR", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite HR',
			'"Playwrite HR Lijeva", "100:200:300:regular", handwriting'                                                                                                                  => 'Playwrite HR Lijeva',
			'"Playwrite HU", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite HU',
			'"Playwrite ID", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite ID',
			'"Playwrite IE", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite IE',
			'"Playwrite IN", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite IN',
			'"Playwrite IS", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite IS',
			'"Playwrite IT Moderna", "100:200:300:regular", handwriting'                                                                                                                 => 'Playwrite IT Moderna',
			'"Playwrite IT Trad", "100:200:300:regular", handwriting'                                                                                                                    => 'Playwrite IT Trad',
			'"Playwrite MX", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite MX',
			'"Playwrite NG Modern", "100:200:300:regular", handwriting'                                                                                                                  => 'Playwrite NG Modern',
			'"Playwrite NL", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite NL',
			'"Playwrite NO", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite NO',
			'"Playwrite NZ", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite NZ',
			'"Playwrite PE", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite PE',
			'"Playwrite PL", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite PL',
			'"Playwrite PT", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite PT',
			'"Playwrite RO", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite RO',
			'"Playwrite SK", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite SK',
			'"Playwrite TZ", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite TZ',
			'"Playwrite US Modern", "100:200:300:regular", handwriting'                                                                                                                  => 'Playwrite US Modern',
			'"Playwrite US Trad", "100:200:300:regular", handwriting'                                                                                                                    => 'Playwrite US Trad',
			'"Playwrite VN", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite VN',
			'"Playwrite ZA", "100:200:300:regular", handwriting'                                                                                                                         => 'Playwrite ZA',
			'"Plus Jakarta Sans", "200:300:regular:500:600:700:800:200italic:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                                      => 'Plus Jakarta Sans',
			'"Podkova", "regular:500:600:700:800", serif'                                                                                                                                => 'Podkova',
			'"Poetsen One", "regular", display'                                                                                                                                          => 'Poetsen One',
			'"Poiret One", "regular", display'                                                                                                                                           => 'Poiret One',
			'"Poller One", "regular", display'                                                                                                                                           => 'Poller One',
			'"Poltawski Nowy", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                        => 'Poltawski Nowy',
			'"Poly", "regular:italic", serif'                                                                                                                                            => 'Poly',
			'"Pompiere", "regular", display'                                                                                                                                             => 'Pompiere',
			'"Pontano Sans", "300:regular:500:600:700", sans-serif'                                                                                                                      => 'Pontano Sans',
			'"Poor Story", "regular", display'                                                                                                                                           => 'Poor Story',
			'"Poppins", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                    => 'Poppins',
			'"Port Lligat Sans", "regular", sans-serif'                                                                                                                                  => 'Port Lligat Sans',
			'"Port Lligat Slab", "regular", serif'                                                                                                                                       => 'Port Lligat Slab',
			'"Potta One", "regular", display'                                                                                                                                            => 'Potta One',
			'"Pragati Narrow", "regular:700", sans-serif'                                                                                                                                => 'Pragati Narrow',
			'"Praise", "regular", handwriting'                                                                                                                                           => 'Praise',
			'"Prata", "regular", serif'                                                                                                                                                  => 'Prata',
			'"Preahvihear", "regular", sans-serif'                                                                                                                                       => 'Preahvihear',
			'"Press Start 2P", "regular", display'                                                                                                                                       => 'Press Start 2P',
			'"Pridi", "200:300:regular:500:600:700", serif'                                                                                                                              => 'Pridi',
			'"Princess Sofia", "regular", handwriting'                                                                                                                                   => 'Princess Sofia',
			'"Prociono", "regular", serif'                                                                                                                                               => 'Prociono',
			'"Prompt", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                     => 'Prompt',
			'"Prosto One", "regular", display'                                                                                                                                           => 'Prosto One',
			'"Protest Guerrilla", "regular", display'                                                                                                                                    => 'Protest Guerrilla',
			'"Protest Revolution", "regular", display'                                                                                                                                   => 'Protest Revolution',
			'"Protest Riot", "regular", display'                                                                                                                                         => 'Protest Riot',
			'"Protest Strike", "regular", display'                                                                                                                                       => 'Protest Strike',
			'"Proza Libre", "regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", sans-serif'                                                                        => 'Proza Libre',
			'"Public Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                => 'Public Sans',
			'"Puppies Play", "regular", handwriting'                                                                                                                                     => 'Puppies Play',
			'"Puritan", "regular:italic:700:700italic", sans-serif'                                                                                                                      => 'Puritan',
			'"Purple Purse", "regular", display'                                                                                                                                         => 'Purple Purse',
			'"Qahiri", "regular", sans-serif'                                                                                                                                            => 'Qahiri',
			'"Quando", "regular", serif'                                                                                                                                                 => 'Quando',
			'"Quantico", "regular:italic:700:700italic", sans-serif'                                                                                                                     => 'Quantico',
			'"Quattrocento", "regular:700", serif'                                                                                                                                       => 'Quattrocento',
			'"Quattrocento Sans", "regular:italic:700:700italic", sans-serif'                                                                                                            => 'Quattrocento Sans',
			'"Questrial", "regular", sans-serif'                                                                                                                                         => 'Questrial',
			'"Quicksand", "300:regular:500:600:700", sans-serif'                                                                                                                         => 'Quicksand',
			'"Quintessential", "regular", handwriting'                                                                                                                                   => 'Quintessential',
			'"Qwigley", "regular", handwriting'                                                                                                                                          => 'Qwigley',
			'"Qwitcher Grypen", "regular:700", handwriting'                                                                                                                              => 'Qwitcher Grypen',
			'"REM", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                        => 'REM',
			'"Racing Sans One", "regular", display'                                                                                                                                      => 'Racing Sans One',
			'"Radio Canada", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", sans-serif'                                                                       => 'Radio Canada',
			'"Radio Canada Big", "regular:500:600:700:italic:500italic:600italic:700italic", sans-serif'                                                                                 => 'Radio Canada Big',
			'"Radley", "regular:italic", serif'                                                                                                                                          => 'Radley',
			'"Rajdhani", "300:regular:500:600:700", sans-serif'                                                                                                                          => 'Rajdhani',
			'"Rakkas", "regular", display'                                                                                                                                               => 'Rakkas',
			'"Raleway", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'Raleway',
			'"Raleway Dots", "regular", display'                                                                                                                                         => 'Raleway Dots',
			'"Ramabhadra", "regular", sans-serif'                                                                                                                                        => 'Ramabhadra',
			'"Ramaraja", "regular", serif'                                                                                                                                               => 'Ramaraja',
			'"Rambla", "regular:italic:700:700italic", sans-serif'                                                                                                                       => 'Rambla',
			'"Rammetto One", "regular", display'                                                                                                                                         => 'Rammetto One',
			'"Rampart One", "regular", display'                                                                                                                                          => 'Rampart One',
			'"Ranchers", "regular", display'                                                                                                                                             => 'Ranchers',
			'"Rancho", "regular", handwriting'                                                                                                                                           => 'Rancho',
			'"Ranga", "regular:700", display'                                                                                                                                            => 'Ranga',
			'"Rasa", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", serif'                                                                                    => 'Rasa',
			'"Rationale", "regular", sans-serif'                                                                                                                                         => 'Rationale',
			'"Ravi Prakash", "regular", display'                                                                                                                                         => 'Ravi Prakash',
			'"Readex Pro", "200:300:regular:500:600:700", sans-serif'                                                                                                                    => 'Readex Pro',
			'"Recursive", "300:regular:500:600:700:800:900", sans-serif'                                                                                                                 => 'Recursive',
			'"Red Hat Display", "300:regular:500:600:700:800:900:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                        => 'Red Hat Display',
			'"Red Hat Mono", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", monospace'                                                                        => 'Red Hat Mono',
			'"Red Hat Text", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", sans-serif'                                                                       => 'Red Hat Text',
			'"Red Rose", "300:regular:500:600:700", display'                                                                                                                             => 'Red Rose',
			'"Redacted", "regular", display'                                                                                                                                             => 'Redacted',
			'"Redacted Script", "300:regular:700", display'                                                                                                                              => 'Redacted Script',
			'"Reddit Mono", "200:300:regular:500:600:700:800:900", monospace'                                                                                                            => 'Reddit Mono',
			'"Reddit Sans", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                              => 'Reddit Sans',
			'"Reddit Sans Condensed", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                 => 'Reddit Sans Condensed',
			'"Redressed", "regular", handwriting'                                                                                                                                        => 'Redressed',
			'"Reem Kufi", "regular:500:600:700", sans-serif'                                                                                                                             => 'Reem Kufi',
			'"Reem Kufi Fun", "regular:500:600:700", sans-serif'                                                                                                                         => 'Reem Kufi Fun',
			'"Reem Kufi Ink", "regular", sans-serif'                                                                                                                                     => 'Reem Kufi Ink',
			'"Reenie Beanie", "regular", handwriting'                                                                                                                                    => 'Reenie Beanie',
			'"Reggae One", "regular", display'                                                                                                                                           => 'Reggae One',
			'"Rethink Sans", "regular:500:600:700:800:italic:500italic:600italic:700italic:800italic", sans-serif'                                                                       => 'Rethink Sans',
			'"Revalia", "regular", display'                                                                                                                                              => 'Revalia',
			'"Rhodium Libre", "regular", serif'                                                                                                                                          => 'Rhodium Libre',
			'"Ribeye", "regular", display'                                                                                                                                               => 'Ribeye',
			'"Ribeye Marrow", "regular", display'                                                                                                                                        => 'Ribeye Marrow',
			'"Righteous", "regular", display'                                                                                                                                            => 'Righteous',
			'"Risque", "regular", display'                                                                                                                                               => 'Risque',
			'"Road Rage", "regular", display'                                                                                                                                            => 'Road Rage',
			'"Roboto", "100:100italic:300:300italic:regular:italic:500:500italic:700:700italic:900:900italic", sans-serif'                                                               => 'Roboto',
			'"Roboto Condensed", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'           => 'Roboto Condensed',
			'"Roboto Flex", "regular", sans-serif'                                                                                                                                       => 'Roboto Flex',
			'"Roboto Mono", "100:200:300:regular:500:600:700:100italic:200italic:300italic:italic:500italic:600italic:700italic", monospace'                                             => 'Roboto Mono',
			'"Roboto Serif", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                    => 'Roboto Serif',
			'"Roboto Slab", "100:200:300:regular:500:600:700:800:900", serif'                                                                                                            => 'Roboto Slab',
			'"Rochester", "regular", handwriting'                                                                                                                                        => 'Rochester',
			'"Rock 3D", "regular", display'                                                                                                                                              => 'Rock 3D',
			'"Rock Salt", "regular", handwriting'                                                                                                                                        => 'Rock Salt',
			'"RocknRoll One", "regular", sans-serif'                                                                                                                                     => 'RocknRoll One',
			'"Rokkitt", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                         => 'Rokkitt',
			'"Romanesco", "regular", handwriting'                                                                                                                                        => 'Romanesco',
			'"Ropa Sans", "regular:italic", sans-serif'                                                                                                                                  => 'Ropa Sans',
			'"Rosario", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", sans-serif'                                                                            => 'Rosario',
			'"Rosarivo", "regular:italic", serif'                                                                                                                                        => 'Rosarivo',
			'"Rouge Script", "regular", handwriting'                                                                                                                                     => 'Rouge Script',
			'"Rowdies", "300:regular:700", display'                                                                                                                                      => 'Rowdies',
			'"Rozha One", "regular", serif'                                                                                                                                              => 'Rozha One',
			'"Rubik", "300:regular:500:600:700:800:900:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                                  => 'Rubik',
			'"Rubik 80s Fade", "regular", display'                                                                                                                                       => 'Rubik 80s Fade',
			'"Rubik Beastly", "regular", display'                                                                                                                                        => 'Rubik Beastly',
			'"Rubik Broken Fax", "regular", display'                                                                                                                                     => 'Rubik Broken Fax',
			'"Rubik Bubbles", "regular", display'                                                                                                                                        => 'Rubik Bubbles',
			'"Rubik Burned", "regular", display'                                                                                                                                         => 'Rubik Burned',
			'"Rubik Dirt", "regular", display'                                                                                                                                           => 'Rubik Dirt',
			'"Rubik Distressed", "regular", display'                                                                                                                                     => 'Rubik Distressed',
			'"Rubik Doodle Shadow", "regular", display'                                                                                                                                  => 'Rubik Doodle Shadow',
			'"Rubik Doodle Triangles", "regular", display'                                                                                                                               => 'Rubik Doodle Triangles',
			'"Rubik Gemstones", "regular", display'                                                                                                                                      => 'Rubik Gemstones',
			'"Rubik Glitch", "regular", display'                                                                                                                                         => 'Rubik Glitch',
			'"Rubik Glitch Pop", "regular", display'                                                                                                                                     => 'Rubik Glitch Pop',
			'"Rubik Iso", "regular", display'                                                                                                                                            => 'Rubik Iso',
			'"Rubik Lines", "regular", display'                                                                                                                                          => 'Rubik Lines',
			'"Rubik Maps", "regular", display'                                                                                                                                           => 'Rubik Maps',
			'"Rubik Marker Hatch", "regular", display'                                                                                                                                   => 'Rubik Marker Hatch',
			'"Rubik Maze", "regular", display'                                                                                                                                           => 'Rubik Maze',
			'"Rubik Microbe", "regular", display'                                                                                                                                        => 'Rubik Microbe',
			'"Rubik Mono One", "regular", sans-serif'                                                                                                                                    => 'Rubik Mono One',
			'"Rubik Moonrocks", "regular", display'                                                                                                                                      => 'Rubik Moonrocks',
			'"Rubik Pixels", "regular", display'                                                                                                                                         => 'Rubik Pixels',
			'"Rubik Puddles", "regular", display'                                                                                                                                        => 'Rubik Puddles',
			'"Rubik Scribble", "regular", display'                                                                                                                                       => 'Rubik Scribble',
			'"Rubik Spray Paint", "regular", display'                                                                                                                                    => 'Rubik Spray Paint',
			'"Rubik Storm", "regular", display'                                                                                                                                          => 'Rubik Storm',
			'"Rubik Vinyl", "regular", display'                                                                                                                                          => 'Rubik Vinyl',
			'"Rubik Wet Paint", "regular", display'                                                                                                                                      => 'Rubik Wet Paint',
			'"Ruda", "regular:500:600:700:800:900", sans-serif'                                                                                                                          => 'Ruda',
			'"Rufina", "regular:700", serif'                                                                                                                                             => 'Rufina',
			'"Ruge Boogie", "regular", handwriting'                                                                                                                                      => 'Ruge Boogie',
			'"Ruluko", "regular", sans-serif'                                                                                                                                            => 'Ruluko',
			'"Rum Raisin", "regular", sans-serif'                                                                                                                                        => 'Rum Raisin',
			'"Ruslan Display", "regular", display'                                                                                                                                       => 'Ruslan Display',
			'"Russo One", "regular", sans-serif'                                                                                                                                         => 'Russo One',
			'"Ruthie", "regular", handwriting'                                                                                                                                           => 'Ruthie',
			'"Ruwudu", "regular:500:600:700", serif'                                                                                                                                     => 'Ruwudu',
			'"Rye", "regular", display'                                                                                                                                                  => 'Rye',
			'"STIX Two Text", "regular:500:600:700:italic:500italic:600italic:700italic", serif'                                                                                         => 'STIX Two Text',
			'"Sacramento", "regular", handwriting'                                                                                                                                       => 'Sacramento',
			'"Sahitya", "regular:700", serif'                                                                                                                                            => 'Sahitya',
			'"Sail", "regular", display'                                                                                                                                                 => 'Sail',
			'"Saira", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                      => 'Saira',
			'"Saira Condensed", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                   => 'Saira Condensed',
			'"Saira Extra Condensed", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                             => 'Saira Extra Condensed',
			'"Saira Semi Condensed", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                              => 'Saira Semi Condensed',
			'"Saira Stencil One", "regular", display'                                                                                                                                    => 'Saira Stencil One',
			'"Salsa", "regular", display'                                                                                                                                                => 'Salsa',
			'"Sanchez", "regular:italic", serif'                                                                                                                                         => 'Sanchez',
			'"Sancreek", "regular", display'                                                                                                                                             => 'Sancreek',
			'"Sankofa Display", "regular", sans-serif'                                                                                                                                   => 'Sankofa Display',
			'"Sansita", "regular:italic:700:700italic:800:800italic:900:900italic", sans-serif'                                                                                          => 'Sansita',
			'"Sansita Swashed", "300:regular:500:600:700:800:900", display'                                                                                                              => 'Sansita Swashed',
			'"Sarabun", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", sans-serif'                                  => 'Sarabun',
			'"Sarala", "regular:700", sans-serif'                                                                                                                                        => 'Sarala',
			'"Sarina", "regular", display'                                                                                                                                               => 'Sarina',
			'"Sarpanch", "regular:500:600:700:800:900", sans-serif'                                                                                                                      => 'Sarpanch',
			'"Sassy Frass", "regular", handwriting'                                                                                                                                      => 'Sassy Frass',
			'"Satisfy", "regular", handwriting'                                                                                                                                          => 'Satisfy',
			'"Sawarabi Gothic", "regular", sans-serif'                                                                                                                                   => 'Sawarabi Gothic',
			'"Sawarabi Mincho", "regular", serif'                                                                                                                                        => 'Sawarabi Mincho',
			'"Scada", "regular:italic:700:700italic", sans-serif'                                                                                                                        => 'Scada',
			'"Scheherazade New", "regular:500:600:700", serif'                                                                                                                           => 'Scheherazade New',
			'"Schibsted Grotesk", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                                                    => 'Schibsted Grotesk',
			'"Schoolbell", "regular", handwriting'                                                                                                                                       => 'Schoolbell',
			'"Scope One", "regular", serif'                                                                                                                                              => 'Scope One',
			'"Seaweed Script", "regular", display'                                                                                                                                       => 'Seaweed Script',
			'"Secular One", "regular", sans-serif'                                                                                                                                       => 'Secular One',
			'"Sedan", "regular:italic", serif'                                                                                                                                           => 'Sedan',
			'"Sedan SC", "regular", serif'                                                                                                                                               => 'Sedan SC',
			'"Sedgwick Ave", "regular", handwriting'                                                                                                                                     => 'Sedgwick Ave',
			'"Sedgwick Ave Display", "regular", handwriting'                                                                                                                             => 'Sedgwick Ave Display',
			'"Sen", "regular:500:600:700:800", sans-serif'                                                                                                                               => 'Sen',
			'"Send Flowers", "regular", handwriting'                                                                                                                                     => 'Send Flowers',
			'"Sevillana", "regular", display'                                                                                                                                            => 'Sevillana',
			'"Seymour One", "regular", sans-serif'                                                                                                                                       => 'Seymour One',
			'"Shadows Into Light", "regular", handwriting'                                                                                                                               => 'Shadows Into Light',
			'"Shadows Into Light Two", "regular", handwriting'                                                                                                                           => 'Shadows Into Light Two',
			'"Shalimar", "regular", handwriting'                                                                                                                                         => 'Shalimar',
			'"Shantell Sans", "300:regular:500:600:700:800:300italic:italic:500italic:600italic:700italic:800italic", display'                                                           => 'Shantell Sans',
			'"Shanti", "regular", sans-serif'                                                                                                                                            => 'Shanti',
			'"Share", "regular:italic:700:700italic", sans-serif'                                                                                                                        => 'Share',
			'"Share Tech", "regular", sans-serif'                                                                                                                                        => 'Share Tech',
			'"Share Tech Mono", "regular", monospace'                                                                                                                                    => 'Share Tech Mono',
			'"Shippori Antique", "regular", sans-serif'                                                                                                                                  => 'Shippori Antique',
			'"Shippori Antique B1", "regular", sans-serif'                                                                                                                               => 'Shippori Antique B1',
			'"Shippori Mincho", "regular:500:600:700:800", serif'                                                                                                                        => 'Shippori Mincho',
			'"Shippori Mincho B1", "regular:500:600:700:800", serif'                                                                                                                     => 'Shippori Mincho B1',
			'"Shizuru", "regular", display'                                                                                                                                              => 'Shizuru',
			'"Shojumaru", "regular", display'                                                                                                                                            => 'Shojumaru',
			'"Short Stack", "regular", handwriting'                                                                                                                                      => 'Short Stack',
			'"Shrikhand", "regular", display'                                                                                                                                            => 'Shrikhand',
			'"Siemreap", "regular", sans-serif'                                                                                                                                          => 'Siemreap',
			'"Sigmar", "regular", display'                                                                                                                                               => 'Sigmar',
			'"Sigmar One", "regular", display'                                                                                                                                           => 'Sigmar One',
			'"Signika", "300:regular:500:600:700", sans-serif'                                                                                                                           => 'Signika',
			'"Signika Negative", "300:regular:500:600:700", sans-serif'                                                                                                                  => 'Signika Negative',
			'"Silkscreen", "regular:700", display'                                                                                                                                       => 'Silkscreen',
			'"Simonetta", "regular:italic:900:900italic", display'                                                                                                                       => 'Simonetta',
			'"Single Day", "regular", display'                                                                                                                                           => 'Single Day',
			'"Sintony", "regular:700", sans-serif'                                                                                                                                       => 'Sintony',
			'"Sirin Stencil", "regular", display'                                                                                                                                        => 'Sirin Stencil',
			'"Six Caps", "regular", sans-serif'                                                                                                                                          => 'Six Caps',
			'"Sixtyfour", "regular", monospace'                                                                                                                                          => 'Sixtyfour',
			'"Skranji", "regular:700", display'                                                                                                                                          => 'Skranji',
			'"Slabo 13px", "regular", serif'                                                                                                                                             => 'Slabo 13px',
			'"Slabo 27px", "regular", serif'                                                                                                                                             => 'Slabo 27px',
			'"Slackey", "regular", display'                                                                                                                                              => 'Slackey',
			'"Slackside One", "regular", handwriting'                                                                                                                                    => 'Slackside One',
			'"Smokum", "regular", display'                                                                                                                                               => 'Smokum',
			'"Smooch", "regular", handwriting'                                                                                                                                           => 'Smooch',
			'"Smooch Sans", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                       => 'Smooch Sans',
			'"Smythe", "regular", display'                                                                                                                                               => 'Smythe',
			'"Sniglet", "regular:800", display'                                                                                                                                          => 'Sniglet',
			'"Snippet", "regular", sans-serif'                                                                                                                                           => 'Snippet',
			'"Snowburst One", "regular", display'                                                                                                                                        => 'Snowburst One',
			'"Sofadi One", "regular", display'                                                                                                                                           => 'Sofadi One',
			'"Sofia", "regular", handwriting'                                                                                                                                            => 'Sofia',
			'"Sofia Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                 => 'Sofia Sans',
			'"Sofia Sans Condensed", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'       => 'Sofia Sans Condensed',
			'"Sofia Sans Extra Condensed", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif' => 'Sofia Sans Extra Condensed',
			'"Sofia Sans Semi Condensed", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'  => 'Sofia Sans Semi Condensed',
			'"Solitreo", "regular", handwriting'                                                                                                                                         => 'Solitreo',
			'"Solway", "300:regular:500:700:800", serif'                                                                                                                                 => 'Solway',
			'"Sometype Mono", "regular:500:600:700:italic:500italic:600italic:700italic", monospace'                                                                                     => 'Sometype Mono',
			'"Song Myung", "regular", serif'                                                                                                                                             => 'Song Myung',
			'"Sono", "200:300:regular:500:600:700:800", sans-serif'                                                                                                                      => 'Sono',
			'"Sonsie One", "regular", display'                                                                                                                                           => 'Sonsie One',
			'"Sora", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                                  => 'Sora',
			'"Sorts Mill Goudy", "regular:italic", serif'                                                                                                                                => 'Sorts Mill Goudy',
			'"Source Code Pro", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", monospace'                           => 'Source Code Pro',
			'"Source Sans 3", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                            => 'Source Sans 3',
			'"Source Serif 4", "200:300:regular:500:600:700:800:900:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                                => 'Source Serif 4',
			'"Space Grotesk", "300:regular:500:600:700", sans-serif'                                                                                                                     => 'Space Grotesk',
			'"Space Mono", "regular:italic:700:700italic", monospace'                                                                                                                    => 'Space Mono',
			'"Special Elite", "regular", display'                                                                                                                                        => 'Special Elite',
			'"Spectral", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", serif'                                                    => 'Spectral',
			'"Spectral SC", "200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", serif'                                                 => 'Spectral SC',
			'"Spicy Rice", "regular", display'                                                                                                                                           => 'Spicy Rice',
			'"Spinnaker", "regular", sans-serif'                                                                                                                                         => 'Spinnaker',
			'"Spirax", "regular", display'                                                                                                                                               => 'Spirax',
			'"Splash", "regular", handwriting'                                                                                                                                           => 'Splash',
			'"Spline Sans", "300:regular:500:600:700", sans-serif'                                                                                                                       => 'Spline Sans',
			'"Spline Sans Mono", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", monospace'                                                                    => 'Spline Sans Mono',
			'"Squada One", "regular", display'                                                                                                                                           => 'Squada One',
			'"Square Peg", "regular", handwriting'                                                                                                                                       => 'Square Peg',
			'"Sree Krushnadevaraya", "regular", serif'                                                                                                                                   => 'Sree Krushnadevaraya',
			'"Sriracha", "regular", handwriting'                                                                                                                                         => 'Sriracha',
			'"Srisakdi", "regular:700", display'                                                                                                                                         => 'Srisakdi',
			'"Staatliches", "regular", display'                                                                                                                                          => 'Staatliches',
			'"Stalemate", "regular", handwriting'                                                                                                                                        => 'Stalemate',
			'"Stalinist One", "regular", display'                                                                                                                                        => 'Stalinist One',
			'"Stardos Stencil", "regular:700", display'                                                                                                                                  => 'Stardos Stencil',
			'"Stick", "regular", sans-serif'                                                                                                                                             => 'Stick',
			'"Stick No Bills", "200:300:regular:500:600:700:800", sans-serif'                                                                                                            => 'Stick No Bills',
			'"Stint Ultra Condensed", "regular", serif'                                                                                                                                  => 'Stint Ultra Condensed',
			'"Stint Ultra Expanded", "regular", serif'                                                                                                                                   => 'Stint Ultra Expanded',
			'"Stoke", "300:regular", serif'                                                                                                                                              => 'Stoke',
			'"Strait", "regular", sans-serif'                                                                                                                                            => 'Strait',
			'"Style Script", "regular", handwriting'                                                                                                                                     => 'Style Script',
			'"Stylish", "regular", sans-serif'                                                                                                                                           => 'Stylish',
			'"Sue Ellen Francisco", "regular", handwriting'                                                                                                                              => 'Sue Ellen Francisco',
			'"Suez One", "regular", serif'                                                                                                                                               => 'Suez One',
			'"Sulphur Point", "300:regular:700", sans-serif'                                                                                                                             => 'Sulphur Point',
			'"Sumana", "regular:700", serif'                                                                                                                                             => 'Sumana',
			'"Sunflower", "300:500:700", sans-serif'                                                                                                                                     => 'Sunflower',
			'"Sunshiney", "regular", handwriting'                                                                                                                                        => 'Sunshiney',
			'"Supermercado One", "regular", display'                                                                                                                                     => 'Supermercado One',
			'"Sura", "regular:700", serif'                                                                                                                                               => 'Sura',
			'"Suranna", "regular", serif'                                                                                                                                                => 'Suranna',
			'"Suravaram", "regular", serif'                                                                                                                                              => 'Suravaram',
			'"Suwannaphum", "100:300:regular:700:900", serif'                                                                                                                            => 'Suwannaphum',
			'"Swanky and Moo Moo", "regular", handwriting'                                                                                                                               => 'Swanky and Moo Moo',
			'"Syncopate", "regular:700", sans-serif'                                                                                                                                     => 'Syncopate',
			'"Syne", "regular:500:600:700:800", sans-serif'                                                                                                                              => 'Syne',
			'"Syne Mono", "regular", monospace'                                                                                                                                          => 'Syne Mono',
			'"Syne Tactile", "regular", display'                                                                                                                                         => 'Syne Tactile',
			'"Tac One", "regular", sans-serif'                                                                                                                                           => 'Tac One',
			'"Tai Heritage Pro", "regular:700", serif'                                                                                                                                   => 'Tai Heritage Pro',
			'"Tajawal", "200:300:regular:500:700:800:900", sans-serif'                                                                                                                   => 'Tajawal',
			'"Tangerine", "regular:700", handwriting'                                                                                                                                    => 'Tangerine',
			'"Tapestry", "regular", handwriting'                                                                                                                                         => 'Tapestry',
			'"Taprom", "regular", display'                                                                                                                                               => 'Taprom',
			'"Tauri", "regular", sans-serif'                                                                                                                                             => 'Tauri',
			'"Taviraj", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", serif'                         => 'Taviraj',
			'"Teachers", "regular:500:600:700:800:italic:500italic:600italic:700italic:800italic", sans-serif'                                                                           => 'Teachers',
			'"Teko", "300:regular:500:600:700", sans-serif'                                                                                                                              => 'Teko',
			'"Tektur", "regular:500:600:700:800:900", display'                                                                                                                           => 'Tektur',
			'"Telex", "regular", sans-serif'                                                                                                                                             => 'Telex',
			'"Tenali Ramakrishna", "regular", sans-serif'                                                                                                                                => 'Tenali Ramakrishna',
			'"Tenor Sans", "regular", sans-serif'                                                                                                                                        => 'Tenor Sans',
			'"Text Me One", "regular", sans-serif'                                                                                                                                       => 'Text Me One',
			'"Texturina", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", serif'                       => 'Texturina',
			'"Thasadith", "regular:italic:700:700italic", sans-serif'                                                                                                                    => 'Thasadith',
			'"The Girl Next Door", "regular", handwriting'                                                                                                                               => 'The Girl Next Door',
			'"The Nautigal", "regular:700", handwriting'                                                                                                                                 => 'The Nautigal',
			'"Tienne", "regular:700:900", serif'                                                                                                                                         => 'Tienne',
			'"Tillana", "regular:500:600:700:800", display'                                                                                                                              => 'Tillana',
			'"Tilt Neon", "regular", display'                                                                                                                                            => 'Tilt Neon',
			'"Tilt Prism", "regular", display'                                                                                                                                           => 'Tilt Prism',
			'"Tilt Warp", "regular", display'                                                                                                                                            => 'Tilt Warp',
			'"Timmana", "regular", sans-serif'                                                                                                                                           => 'Timmana',
			'"Tinos", "regular:italic:700:700italic", serif'                                                                                                                             => 'Tinos',
			'"Tiny5", "regular", sans-serif'                                                                                                                                             => 'Tiny5',
			'"Tiro Bangla", "regular:italic", serif'                                                                                                                                     => 'Tiro Bangla',
			'"Tiro Devanagari Hindi", "regular:italic", serif'                                                                                                                           => 'Tiro Devanagari Hindi',
			'"Tiro Devanagari Marathi", "regular:italic", serif'                                                                                                                         => 'Tiro Devanagari Marathi',
			'"Tiro Devanagari Sanskrit", "regular:italic", serif'                                                                                                                        => 'Tiro Devanagari Sanskrit',
			'"Tiro Gurmukhi", "regular:italic", serif'                                                                                                                                   => 'Tiro Gurmukhi',
			'"Tiro Kannada", "regular:italic", serif'                                                                                                                                    => 'Tiro Kannada',
			'"Tiro Tamil", "regular:italic", serif'                                                                                                                                      => 'Tiro Tamil',
			'"Tiro Telugu", "regular:italic", serif'                                                                                                                                     => 'Tiro Telugu',
			'"Titan One", "regular", display'                                                                                                                                            => 'Titan One',
			'"Titillium Web", "200:200italic:300:300italic:regular:italic:600:600italic:700:700italic:900", sans-serif'                                                                  => 'Titillium Web',
			'"Tomorrow", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", sans-serif'                   => 'Tomorrow',
			'"Tourney", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", display'                       => 'Tourney',
			'"Trade Winds", "regular", display'                                                                                                                                          => 'Trade Winds',
			'"Train One", "regular", display'                                                                                                                                            => 'Train One',
			'"Trirong", "100:100italic:200:200italic:300:300italic:regular:italic:500:500italic:600:600italic:700:700italic:800:800italic:900:900italic", serif'                         => 'Trirong',
			'"Trispace", "100:200:300:regular:500:600:700:800", sans-serif'                                                                                                              => 'Trispace',
			'"Trocchi", "regular", serif'                                                                                                                                                => 'Trocchi',
			'"Trochut", "regular:italic:700", display'                                                                                                                                   => 'Trochut',
			'"Truculenta", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                        => 'Truculenta',
			'"Trykker", "regular", serif'                                                                                                                                                => 'Trykker',
			'"Tsukimi Rounded", "300:regular:500:600:700", sans-serif'                                                                                                                   => 'Tsukimi Rounded',
			'"Tulpen One", "regular", display'                                                                                                                                           => 'Tulpen One',
			'"Turret Road", "200:300:regular:500:700:800", display'                                                                                                                      => 'Turret Road',
			'"Twinkle Star", "regular", handwriting'                                                                                                                                     => 'Twinkle Star',
			'"Ubuntu", "300:300italic:regular:italic:500:500italic:700:700italic", sans-serif'                                                                                           => 'Ubuntu',
			'"Ubuntu Condensed", "regular", sans-serif'                                                                                                                                  => 'Ubuntu Condensed',
			'"Ubuntu Mono", "regular:italic:700:700italic", monospace'                                                                                                                   => 'Ubuntu Mono',
			'"Ubuntu Sans", "100:200:300:regular:500:600:700:800:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic", sans-serif'                              => 'Ubuntu Sans',
			'"Ubuntu Sans Mono", "regular:500:600:700:italic:500italic:600italic:700italic", monospace'                                                                                  => 'Ubuntu Sans Mono',
			'"Uchen", "regular", serif'                                                                                                                                                  => 'Uchen',
			'"Ultra", "regular", serif'                                                                                                                                                  => 'Ultra',
			'"Unbounded", "200:300:regular:500:600:700:800:900", sans-serif'                                                                                                             => 'Unbounded',
			'"Uncial Antiqua", "regular", display'                                                                                                                                       => 'Uncial Antiqua',
			'"Underdog", "regular", display'                                                                                                                                             => 'Underdog',
			'"Unica One", "regular", display'                                                                                                                                            => 'Unica One',
			'"UnifrakturCook", "700", display'                                                                                                                                           => 'UnifrakturCook',
			'"UnifrakturMaguntia", "regular", display'                                                                                                                                   => 'UnifrakturMaguntia',
			'"Unkempt", "regular:700", display'                                                                                                                                          => 'Unkempt',
			'"Unlock", "regular", display'                                                                                                                                               => 'Unlock',
			'"Unna", "regular:italic:700:700italic", serif'                                                                                                                              => 'Unna',
			'"Updock", "regular", handwriting'                                                                                                                                           => 'Updock',
			'"Urbanist", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                   => 'Urbanist',
			'"VT323", "regular", monospace'                                                                                                                                              => 'VT323',
			'"Vampiro One", "regular", display'                                                                                                                                          => 'Vampiro One',
			'"Varela", "regular", sans-serif'                                                                                                                                            => 'Varela',
			'"Varela Round", "regular", sans-serif'                                                                                                                                      => 'Varela Round',
			'"Varta", "300:regular:500:600:700", sans-serif'                                                                                                                             => 'Varta',
			'"Vast Shadow", "regular", serif'                                                                                                                                            => 'Vast Shadow',
			'"Vazirmatn", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                         => 'Vazirmatn',
			'"Vesper Libre", "regular:500:700:900", serif'                                                                                                                               => 'Vesper Libre',
			'"Viaoda Libre", "regular", display'                                                                                                                                         => 'Viaoda Libre',
			'"Vibes", "regular", display'                                                                                                                                                => 'Vibes',
			'"Vibur", "regular", handwriting'                                                                                                                                            => 'Vibur',
			'"Victor Mono", "100:200:300:regular:500:600:700:100italic:200italic:300italic:italic:500italic:600italic:700italic", monospace'                                             => 'Victor Mono',
			'"Vidaloka", "regular", serif'                                                                                                                                               => 'Vidaloka',
			'"Viga", "regular", sans-serif'                                                                                                                                              => 'Viga',
			'"Vina Sans", "regular", display'                                                                                                                                            => 'Vina Sans',
			'"Voces", "regular", sans-serif'                                                                                                                                             => 'Voces',
			'"Volkhov", "regular:italic:700:700italic", serif'                                                                                                                           => 'Volkhov',
			'"Vollkorn", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                                  => 'Vollkorn',
			'"Vollkorn SC", "regular:600:700:900", serif'                                                                                                                                => 'Vollkorn SC',
			'"Voltaire", "regular", sans-serif'                                                                                                                                          => 'Voltaire',
			'"Vujahday Script", "regular", handwriting'                                                                                                                                  => 'Vujahday Script',
			'"Waiting for the Sunrise", "regular", handwriting'                                                                                                                          => 'Waiting for the Sunrise',
			'"Wallpoet", "regular", display'                                                                                                                                             => 'Wallpoet',
			'"Walter Turncoat", "regular", handwriting'                                                                                                                                  => 'Walter Turncoat',
			'"Warnes", "regular", display'                                                                                                                                               => 'Warnes',
			'"Water Brush", "regular", handwriting'                                                                                                                                      => 'Water Brush',
			'"Waterfall", "regular", handwriting'                                                                                                                                        => 'Waterfall',
			'"Wavefont", "100:200:300:regular:500:600:700:800:900", display'                                                                                                             => 'Wavefont',
			'"Wellfleet", "regular", serif'                                                                                                                                              => 'Wellfleet',
			'"Wendy One", "regular", sans-serif'                                                                                                                                         => 'Wendy One',
			'"Whisper", "regular", handwriting'                                                                                                                                          => 'Whisper',
			'"WindSong", "regular:500", handwriting'                                                                                                                                     => 'WindSong',
			'"Wire One", "regular", sans-serif'                                                                                                                                          => 'Wire One',
			'"Wittgenstein", "regular:500:600:700:800:900:italic:500italic:600italic:700italic:800italic:900italic", serif'                                                              => 'Wittgenstein',
			'"Wix Madefor Display", "regular:500:600:700:800", sans-serif'                                                                                                               => 'Wix Madefor Display',
			'"Wix Madefor Text", "regular:italic:500:500italic:600:600italic:700:700italic:800:800italic", sans-serif'                                                                   => 'Wix Madefor Text',
			'"Work Sans", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                  => 'Work Sans',
			'"Workbench", "regular", monospace'                                                                                                                                          => 'Workbench',
			'"Xanh Mono", "regular:italic", monospace'                                                                                                                                   => 'Xanh Mono',
			'"Yaldevi", "200:300:regular:500:600:700", sans-serif'                                                                                                                       => 'Yaldevi',
			'"Yanone Kaffeesatz", "200:300:regular:500:600:700", sans-serif'                                                                                                             => 'Yanone Kaffeesatz',
			'"Yantramanav", "100:300:regular:500:700:900", sans-serif'                                                                                                                   => 'Yantramanav',
			'"Yarndings 12", "regular", display'                                                                                                                                         => 'Yarndings 12',
			'"Yarndings 12 Charted", "regular", display'                                                                                                                                 => 'Yarndings 12 Charted',
			'"Yarndings 20", "regular", display'                                                                                                                                         => 'Yarndings 20',
			'"Yarndings 20 Charted", "regular", display'                                                                                                                                 => 'Yarndings 20 Charted',
			'"Yatra One", "regular", display'                                                                                                                                            => 'Yatra One',
			'"Yellowtail", "regular", handwriting'                                                                                                                                       => 'Yellowtail',
			'"Yeon Sung", "regular", display'                                                                                                                                            => 'Yeon Sung',
			'"Yeseva One", "regular", display'                                                                                                                                           => 'Yeseva One',
			'"Yesteryear", "regular", handwriting'                                                                                                                                       => 'Yesteryear',
			'"Yomogi", "regular", handwriting'                                                                                                                                           => 'Yomogi',
			'"Young Serif", "regular", serif'                                                                                                                                            => 'Young Serif',
			'"Yrsa", "300:regular:500:600:700:300italic:italic:500italic:600italic:700italic", serif'                                                                                    => 'Yrsa',
			'"Ysabeau", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'                    => 'Ysabeau',
			'"Ysabeau Infant", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'             => 'Ysabeau Infant',
			'"Ysabeau Office", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif'             => 'Ysabeau Office',
			'"Ysabeau SC", "100:200:300:regular:500:600:700:800:900", sans-serif'                                                                                                        => 'Ysabeau SC',
			'"Yuji Boku", "regular", serif'                                                                                                                                              => 'Yuji Boku',
			'"Yuji Hentaigana Akari", "regular", handwriting'                                                                                                                            => 'Yuji Hentaigana Akari',
			'"Yuji Hentaigana Akebono", "regular", handwriting'                                                                                                                          => 'Yuji Hentaigana Akebono',
			'"Yuji Mai", "regular", serif'                                                                                                                                               => 'Yuji Mai',
			'"Yuji Syuku", "regular", serif'                                                                                                                                             => 'Yuji Syuku',
			'"Yusei Magic", "regular", sans-serif'                                                                                                                                       => 'Yusei Magic',
			'"ZCOOL KuaiLe", "regular", sans-serif'                                                                                                                                      => 'ZCOOL KuaiLe',
			'"ZCOOL QingKe HuangYou", "regular", sans-serif'                                                                                                                             => 'ZCOOL QingKe HuangYou',
			'"ZCOOL XiaoWei", "regular", sans-serif'                                                                                                                                     => 'ZCOOL XiaoWei',
			'"Zain", "200:300:regular:700:800:900", sans-serif'                                                                                                                          => 'Zain',
			'"Zen Antique", "regular", serif'                                                                                                                                            => 'Zen Antique',
			'"Zen Antique Soft", "regular", serif'                                                                                                                                       => 'Zen Antique Soft',
			'"Zen Dots", "regular", display'                                                                                                                                             => 'Zen Dots',
			'"Zen Kaku Gothic Antique", "300:regular:500:700:900", sans-serif'                                                                                                           => 'Zen Kaku Gothic Antique',
			'"Zen Kaku Gothic New", "300:regular:500:700:900", sans-serif'                                                                                                               => 'Zen Kaku Gothic New',
			'"Zen Kurenaido", "regular", sans-serif'                                                                                                                                     => 'Zen Kurenaido',
			'"Zen Loop", "regular:italic", display'                                                                                                                                      => 'Zen Loop',
			'"Zen Maru Gothic", "300:regular:500:700:900", sans-serif'                                                                                                                   => 'Zen Maru Gothic',
			'"Zen Old Mincho", "regular:500:600:700:900", serif'                                                                                                                         => 'Zen Old Mincho',
			'"Zen Tokyo Zoo", "regular", display'                                                                                                                                        => 'Zen Tokyo Zoo',
			'"Zeyada", "regular", handwriting'                                                                                                                                           => 'Zeyada',
			'"Zhi Mang Xing", "regular", handwriting'                                                                                                                                    => 'Zhi Mang Xing',
			'"Zilla Slab", "300:300italic:regular:italic:500:500italic:600:600italic:700:700italic", serif'                                                                              => 'Zilla Slab',
			'"Zilla Slab Highlight", "regular:700", serif'                                                                                                                               => 'Zilla Slab Highlight',
		];

		return $penci_soledad_google_fonts;
	}
}